/* NOTE: This file was generated as an optimized version of "library.source.less" for the Theme Designer. */

/*!
 * OpenUI5
 * (c) Copyright 2009-2025 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

/* START "skeleton.less" */
// /**
// * Copyright (c) 2012-2025 SAP SE or an SAP affiliate company. All rights reserved.
// * Theming Engine 15.0.1
// * data:{"sModified":"2025-03-20T15:24:52Z"}
// */


/******************* FILE /Base/baseLib/baseTheme/skeleton.less (Version 11.28.2) *******************/

/*!SAP_POSTPROCESS_REDUCE_START*/

:root {
  --sapBrandColor: @sapBrandColor;
  --sapHighlightColor: @sapHighlightColor;
  --sapBaseColor: @sapBaseColor;
  --sapShellColor: @sapShellColor;
  --sapBackgroundColor: @sapBackgroundColor;
  --sapFontFamily: @sapFontFamily;
  --sapFontSize: @sapFontSize;
  --sapTextColor: @sapTextColor;
  --sapLinkColor: @sapLinkColor;
  --sapCompanyLogo: @sapCompanyLogo;
  --sapFavicon: @sapFavicon;
  --sapBackgroundImage: @sapBackgroundImage;
  --sapBackgroundImageOpacity: @sapBackgroundImageOpacity;
  --sapBackgroundImageRepeat: @sapBackgroundImageRepeat;
  --sapSelectedColor: @sapSelectedColor;
  --sapHoverColor: @sapHoverColor;
  --sapActiveColor: @sapActiveColor;
  --sapHighlightTextColor: @sapHighlightTextColor;
  --sapTitleColor: @sapTitleColor;
  --sapNegativeColor: @sapNegativeColor;
  --sapCriticalColor: @sapCriticalColor;
  --sapPositiveColor: @sapPositiveColor;
  --sapInformativeColor: @sapInformativeColor;
  --sapNeutralColor: @sapNeutralColor;
  --sapNegativeElementColor: @sapNegativeElementColor;
  --sapCriticalElementColor: @sapCriticalElementColor;
  --sapPositiveElementColor: @sapPositiveElementColor;
  --sapInformativeElementColor: @sapInformativeElementColor;
  --sapNeutralElementColor: @sapNeutralElementColor;
  --sapNegativeTextColor: @sapNegativeTextColor;
  --sapCriticalTextColor: @sapCriticalTextColor;
  --sapPositiveTextColor: @sapPositiveTextColor;
  --sapInformativeTextColor: @sapInformativeTextColor;
  --sapNeutralTextColor: @sapNeutralTextColor;
  --sapErrorColor: @sapErrorColor;
  --sapWarningColor: @sapWarningColor;
  --sapSuccessColor: @sapSuccessColor;
  --sapInformationColor: @sapInformationColor;
  --sapErrorBackground: @sapErrorBackground;
  --sapWarningBackground: @sapWarningBackground;
  --sapSuccessBackground: @sapSuccessBackground;
  --sapInformationBackground: @sapInformationBackground;
  --sapNeutralBackground: @sapNeutralBackground;
  --sapErrorBorderColor: @sapErrorBorderColor;
  --sapWarningBorderColor: @sapWarningBorderColor;
  --sapSuccessBorderColor: @sapSuccessBorderColor;
  --sapInformationBorderColor: @sapInformationBorderColor;
  --sapNeutralBorderColor: @sapNeutralBorderColor;
  --sapElement_LineHeight: @sapElement_LineHeight;
  --sapElement_Height: @sapElement_Height;
  --sapElement_BorderWidth: @sapElement_BorderWidth;
  --sapElement_BorderCornerRadius: @sapElement_BorderCornerRadius;
  --sapElement_Compact_LineHeight: @sapElement_Compact_LineHeight;
  --sapElement_Compact_Height: @sapElement_Compact_Height;
  --sapElement_Condensed_LineHeight: @sapElement_Condensed_LineHeight;
  --sapElement_Condensed_Height: @sapElement_Condensed_Height;
  --sapContent_LineHeight: @sapContent_LineHeight;
  --sapContent_IconHeight: @sapContent_IconHeight;
  --sapContent_IconColor: @sapContent_IconColor;
  --sapContent_ContrastIconColor: @sapContent_ContrastIconColor;
  --sapContent_NonInteractiveIconColor: @sapContent_NonInteractiveIconColor;
  --sapContent_MarkerIconColor: @sapContent_MarkerIconColor;
  --sapContent_MarkerTextColor: @sapContent_MarkerTextColor;
  --sapContent_MeasureIndicatorColor: @sapContent_MeasureIndicatorColor;
  --sapContent_Selected_MeasureIndicatorColor: @sapContent_Selected_MeasureIndicatorColor;
  --sapContent_Placeholderloading_Background: @sapContent_Placeholderloading_Background;
  --sapContent_Placeholderloading_Gradient: @sapContent_Placeholderloading_Gradient;
  --sapContent_ImagePlaceholderBackground: @sapContent_ImagePlaceholderBackground;
  --sapContent_ImagePlaceholderForegroundColor: @sapContent_ImagePlaceholderForegroundColor;
  --sapContent_RatedColor: @sapContent_RatedColor;
  --sapContent_UnratedColor: @sapContent_UnratedColor;
  --sapContent_BusyColor: @sapContent_BusyColor;
  --sapContent_FocusColor: @sapContent_FocusColor;
  --sapContent_FocusStyle: @sapContent_FocusStyle;
  --sapContent_FocusWidth: @sapContent_FocusWidth;
  --sapContent_ContrastFocusColor: @sapContent_ContrastFocusColor;
  --sapContent_ShadowColor: @sapContent_ShadowColor;
  --sapContent_ContrastShadowColor: @sapContent_ContrastShadowColor;
  --sapContent_Shadow0: @sapContent_Shadow0;
  --sapContent_Shadow1: @sapContent_Shadow1;
  --sapContent_Shadow2: @sapContent_Shadow2;
  --sapContent_Shadow3: @sapContent_Shadow3;
  --sapContent_TextShadow: @sapContent_TextShadow;
  --sapContent_ContrastTextShadow: @sapContent_ContrastTextShadow;
  --sapContent_HeaderShadow: @sapContent_HeaderShadow;
  --sapContent_Interaction_Shadow: @sapContent_Interaction_Shadow;
  --sapContent_Selected_Shadow: @sapContent_Selected_Shadow;
  --sapContent_Negative_Shadow: @sapContent_Negative_Shadow;
  --sapContent_Critical_Shadow: @sapContent_Critical_Shadow;
  --sapContent_Positive_Shadow: @sapContent_Positive_Shadow;
  --sapContent_Informative_Shadow: @sapContent_Informative_Shadow;
  --sapContent_Neutral_Shadow: @sapContent_Neutral_Shadow;
  --sapContent_SearchHighlightColor: @sapContent_SearchHighlightColor;
  --sapContent_HelpColor: @sapContent_HelpColor;
  --sapContent_LabelColor: @sapContent_LabelColor;
  --sapContent_MonospaceFontFamily: @sapContent_MonospaceFontFamily;
  --sapContent_MonospaceBoldFontFamily: @sapContent_MonospaceBoldFontFamily;
  --sapContent_IconFontFamily: @sapContent_IconFontFamily;
  --sapContent_DisabledTextColor: @sapContent_DisabledTextColor;
  --sapContent_DisabledOpacity: @sapContent_DisabledOpacity;
  --sapContent_ContrastTextThreshold: @sapContent_ContrastTextThreshold;
  --sapContent_ContrastTextColor: @sapContent_ContrastTextColor;
  --sapContent_ForegroundColor: @sapContent_ForegroundColor;
  --sapContent_ForegroundBorderColor: @sapContent_ForegroundBorderColor;
  --sapContent_ForegroundTextColor: @sapContent_ForegroundTextColor;
  --sapContent_BadgeBackground: @sapContent_BadgeBackground;
  --sapContent_BadgeTextColor: @sapContent_BadgeTextColor;
  --sapContent_BadgeBorderColor: @sapContent_BadgeBorderColor;
  --sapContent_DragAndDropActiveColor: @sapContent_DragAndDropActiveColor;
  --sapContent_Selected_TextColor: @sapContent_Selected_TextColor;
  --sapContent_Selected_Background: @sapContent_Selected_Background;
  --sapContent_Selected_Hover_Background: @sapContent_Selected_Hover_Background;
  --sapContent_Selected_ForegroundColor: @sapContent_Selected_ForegroundColor;
  --sapContent_ForcedColorAdjust: @sapContent_ForcedColorAdjust;
  --sapContent_Lite_Shadow: @sapContent_Lite_Shadow;
  --sapContent_Illustrative_Color1: @sapContent_Illustrative_Color1;
  --sapContent_Illustrative_Color2: @sapContent_Illustrative_Color2;
  --sapContent_Illustrative_Color3: @sapContent_Illustrative_Color3;
  --sapContent_Illustrative_Color4: @sapContent_Illustrative_Color4;
  --sapContent_Illustrative_Color5: @sapContent_Illustrative_Color5;
  --sapContent_Illustrative_Color6: @sapContent_Illustrative_Color6;
  --sapContent_Illustrative_Color7: @sapContent_Illustrative_Color7;
  --sapContent_Illustrative_Color8: @sapContent_Illustrative_Color8;
  --sapContent_Illustrative_Color9: @sapContent_Illustrative_Color9;
  --sapContent_Illustrative_Color10: @sapContent_Illustrative_Color10;
  --sapContent_Illustrative_Color11: @sapContent_Illustrative_Color11;
  --sapContent_Illustrative_Color12: @sapContent_Illustrative_Color12;
  --sapContent_Illustrative_Color13: @sapContent_Illustrative_Color13;
  --sapContent_Illustrative_Color14: @sapContent_Illustrative_Color14;
  --sapContent_Illustrative_Color15: @sapContent_Illustrative_Color15;
  --sapContent_Illustrative_Color16: @sapContent_Illustrative_Color16;
  --sapContent_Illustrative_Color17: @sapContent_Illustrative_Color17;
  --sapContent_Illustrative_Color18: @sapContent_Illustrative_Color18;
  --sapContent_Illustrative_Color19: @sapContent_Illustrative_Color19;
  --sapContent_Illustrative_Color20: @sapContent_Illustrative_Color20;
  --sapContent_Illustrative_Color21: @sapContent_Illustrative_Color21;
  --sapContent_Illustrative_Color22: @sapContent_Illustrative_Color22;
  --sapContent_Illustrative_Color23: @sapContent_Illustrative_Color23;
  --sapContent_Illustrative_Color24: @sapContent_Illustrative_Color24;
  --sapContent_Illustrative_Color25: @sapContent_Illustrative_Color25;
  --sapContent_Illustrative_Color26: @sapContent_Illustrative_Color26;
  --sapContent_Illustrative_Color27: @sapContent_Illustrative_Color27;
  --sapContent_Illustrative_Color28: @sapContent_Illustrative_Color28;
  --sapContent_Illustrative_Color29: @sapContent_Illustrative_Color29;
  --sapContent_Illustrative_Color30: @sapContent_Illustrative_Color30;
  --sapContent_Illustrative_Color31: @sapContent_Illustrative_Color31;
  --sapContent_Space_S: @sapContent_Space_S;
  --sapContent_Space_M: @sapContent_Space_M;
  --sapContent_Space_L: @sapContent_Space_L;
  --sapContent_Space_XL: @sapContent_Space_XL;
  --sapContent_Space_Tiny: @sapContent_Space_Tiny;
  --sapContent_Space_Small: @sapContent_Space_Small;
  --sapContent_Space_Medium: @sapContent_Space_Medium;
  --sapContent_Space_Large: @sapContent_Space_Large;
  --sapContent_Margin_Tiny: @sapContent_Margin_Tiny;
  --sapContent_Margin_Small: @sapContent_Margin_Small;
  --sapContent_Margin_Medium: @sapContent_Margin_Medium;
  --sapContent_Margin_Large: @sapContent_Margin_Large;
  --sapContent_Padding_S: @sapContent_Padding_S;
  --sapContent_Padding_M: @sapContent_Padding_M;
  --sapContent_Padding_L: @sapContent_Padding_L;
  --sapContent_Padding_XL: @sapContent_Padding_XL;
  --sapContent_Gap: @sapContent_Gap;
  --sapContent_Success_HeaderShadow: @sapContent_Success_HeaderShadow;
  --sapContent_Warning_HeaderShadow: @sapContent_Warning_HeaderShadow;
  --sapContent_Error_HeaderShadow: @sapContent_Error_HeaderShadow;
  --sapContent_Information_HeaderShadow: @sapContent_Information_HeaderShadow;
  --sapFontLightFamily: @sapFontLightFamily;
  --sapFontBoldFamily: @sapFontBoldFamily;
  --sapFontSemiboldFamily: @sapFontSemiboldFamily;
  --sapFontSemiboldDuplexFamily: @sapFontSemiboldDuplexFamily;
  --sapFontBlackFamily: @sapFontBlackFamily;
  --sapFontHeaderFamily: @sapFontHeaderFamily;
  --sapFontSmallSize: @sapFontSmallSize;
  --sapFontLargeSize: @sapFontLargeSize;
  --sapFontHeader1Size: @sapFontHeader1Size;
  --sapFontHeader2Size: @sapFontHeader2Size;
  --sapFontHeader3Size: @sapFontHeader3Size;
  --sapFontHeader4Size: @sapFontHeader4Size;
  --sapFontHeader5Size: @sapFontHeader5Size;
  --sapFontHeader6Size: @sapFontHeader6Size;
  --sapLink_TextDecoration: @sapLink_TextDecoration;
  --sapLink_Hover_Color: @sapLink_Hover_Color;
  --sapLink_Hover_TextDecoration: @sapLink_Hover_TextDecoration;
  --sapLink_Active_Color: @sapLink_Active_Color;
  --sapLink_Active_TextDecoration: @sapLink_Active_TextDecoration;
  --sapLink_Visited_Color: @sapLink_Visited_Color;
  --sapLink_InvertedColor: @sapLink_InvertedColor;
  --sapLink_SubtleColor: @sapLink_SubtleColor;
  --sapShell_Background: @sapShell_Background;
  --sapShell_BackgroundImage: @sapShell_BackgroundImage;
  --sapShell_BackgroundImageOpacity: @sapShell_BackgroundImageOpacity;
  --sapShell_BackgroundImageRepeat: @sapShell_BackgroundImageRepeat;
  --sapShell_BorderColor: @sapShell_BorderColor;
  --sapShell_TextColor: @sapShell_TextColor;
  --sapShell_InteractiveBackground: @sapShell_InteractiveBackground;
  --sapShell_InteractiveTextColor: @sapShell_InteractiveTextColor;
  --sapShell_InteractiveBorderColor: @sapShell_InteractiveBorderColor;
  --sapShell_GroupTitleTextColor: @sapShell_GroupTitleTextColor;
  --sapShell_GroupTitleTextShadow: @sapShell_GroupTitleTextShadow;
  --sapShell_Hover_Background: @sapShell_Hover_Background;
  --sapShell_Active_Background: @sapShell_Active_Background;
  --sapShell_Active_TextColor: @sapShell_Active_TextColor;
  --sapShell_Selected_Background: @sapShell_Selected_Background;
  --sapShell_Selected_TextColor: @sapShell_Selected_TextColor;
  --sapShell_Selected_Hover_Background: @sapShell_Selected_Hover_Background;
  --sapShell_Favicon: @sapShell_Favicon;
  --sapShell_Navigation_Background: @sapShell_Navigation_Background;
  --sapShell_Navigation_Hover_Background: @sapShell_Navigation_Hover_Background;
  --sapShell_Navigation_SelectedColor: @sapShell_Navigation_SelectedColor;
  --sapShell_Navigation_Selected_TextColor: @sapShell_Navigation_Selected_TextColor;
  --sapShell_Navigation_TextColor: @sapShell_Navigation_TextColor;
  --sapShell_Navigation_Active_TextColor: @sapShell_Navigation_Active_TextColor;
  --sapShell_Navigation_Active_Background: @sapShell_Navigation_Active_Background;
  --sapShell_Shadow: @sapShell_Shadow;
  --sapShell_NegativeColor: @sapShell_NegativeColor;
  --sapShell_CriticalColor: @sapShell_CriticalColor;
  --sapShell_PositiveColor: @sapShell_PositiveColor;
  --sapShell_InformativeColor: @sapShell_InformativeColor;
  --sapShell_NeutralColor: @sapShell_NeutralColor;
  --sapShell_Assistant_ForegroundColor: @sapShell_Assistant_ForegroundColor;
  --sapShell_SubBrand_TextColor: @sapShell_SubBrand_TextColor;
  --sapShell_Category_1_Background: @sapShell_Category_1_Background;
  --sapShell_Category_1_BorderColor: @sapShell_Category_1_BorderColor;
  --sapShell_Category_1_TextColor: @sapShell_Category_1_TextColor;
  --sapShell_Category_1_TextShadow: @sapShell_Category_1_TextShadow;
  --sapShell_Category_2_Background: @sapShell_Category_2_Background;
  --sapShell_Category_2_BorderColor: @sapShell_Category_2_BorderColor;
  --sapShell_Category_2_TextColor: @sapShell_Category_2_TextColor;
  --sapShell_Category_2_TextShadow: @sapShell_Category_2_TextShadow;
  --sapShell_Category_3_Background: @sapShell_Category_3_Background;
  --sapShell_Category_3_BorderColor: @sapShell_Category_3_BorderColor;
  --sapShell_Category_3_TextColor: @sapShell_Category_3_TextColor;
  --sapShell_Category_3_TextShadow: @sapShell_Category_3_TextShadow;
  --sapShell_Category_4_Background: @sapShell_Category_4_Background;
  --sapShell_Category_4_BorderColor: @sapShell_Category_4_BorderColor;
  --sapShell_Category_4_TextColor: @sapShell_Category_4_TextColor;
  --sapShell_Category_4_TextShadow: @sapShell_Category_4_TextShadow;
  --sapShell_Category_5_Background: @sapShell_Category_5_Background;
  --sapShell_Category_5_BorderColor: @sapShell_Category_5_BorderColor;
  --sapShell_Category_5_TextColor: @sapShell_Category_5_TextColor;
  --sapShell_Category_5_TextShadow: @sapShell_Category_5_TextShadow;
  --sapShell_Category_6_Background: @sapShell_Category_6_Background;
  --sapShell_Category_6_BorderColor: @sapShell_Category_6_BorderColor;
  --sapShell_Category_6_TextColor: @sapShell_Category_6_TextColor;
  --sapShell_Category_6_TextShadow: @sapShell_Category_6_TextShadow;
  --sapShell_Category_7_Background: @sapShell_Category_7_Background;
  --sapShell_Category_7_BorderColor: @sapShell_Category_7_BorderColor;
  --sapShell_Category_7_TextColor: @sapShell_Category_7_TextColor;
  --sapShell_Category_7_TextShadow: @sapShell_Category_7_TextShadow;
  --sapShell_Category_8_Background: @sapShell_Category_8_Background;
  --sapShell_Category_8_BorderColor: @sapShell_Category_8_BorderColor;
  --sapShell_Category_8_TextColor: @sapShell_Category_8_TextColor;
  --sapShell_Category_8_TextShadow: @sapShell_Category_8_TextShadow;
  --sapShell_Category_9_Background: @sapShell_Category_9_Background;
  --sapShell_Category_9_BorderColor: @sapShell_Category_9_BorderColor;
  --sapShell_Category_9_TextColor: @sapShell_Category_9_TextColor;
  --sapShell_Category_9_TextShadow: @sapShell_Category_9_TextShadow;
  --sapShell_Category_10_Background: @sapShell_Category_10_Background;
  --sapShell_Category_10_BorderColor: @sapShell_Category_10_BorderColor;
  --sapShell_Category_10_TextColor: @sapShell_Category_10_TextColor;
  --sapShell_Category_10_TextShadow: @sapShell_Category_10_TextShadow;
  --sapShell_Category_11_Background: @sapShell_Category_11_Background;
  --sapShell_Category_11_BorderColor: @sapShell_Category_11_BorderColor;
  --sapShell_Category_11_TextColor: @sapShell_Category_11_TextColor;
  --sapShell_Category_11_TextShadow: @sapShell_Category_11_TextShadow;
  --sapShell_Category_12_Background: @sapShell_Category_12_Background;
  --sapShell_Category_12_BorderColor: @sapShell_Category_12_BorderColor;
  --sapShell_Category_12_TextColor: @sapShell_Category_12_TextColor;
  --sapShell_Category_12_TextShadow: @sapShell_Category_12_TextShadow;
  --sapShell_Category_13_Background: @sapShell_Category_13_Background;
  --sapShell_Category_13_BorderColor: @sapShell_Category_13_BorderColor;
  --sapShell_Category_13_TextColor: @sapShell_Category_13_TextColor;
  --sapShell_Category_13_TextShadow: @sapShell_Category_13_TextShadow;
  --sapShell_Category_14_Background: @sapShell_Category_14_Background;
  --sapShell_Category_14_BorderColor: @sapShell_Category_14_BorderColor;
  --sapShell_Category_14_TextColor: @sapShell_Category_14_TextColor;
  --sapShell_Category_14_TextShadow: @sapShell_Category_14_TextShadow;
  --sapShell_Category_15_Background: @sapShell_Category_15_Background;
  --sapShell_Category_15_BorderColor: @sapShell_Category_15_BorderColor;
  --sapShell_Category_15_TextColor: @sapShell_Category_15_TextColor;
  --sapShell_Category_15_TextShadow: @sapShell_Category_15_TextShadow;
  --sapShell_Category_16_Background: @sapShell_Category_16_Background;
  --sapShell_Category_16_BorderColor: @sapShell_Category_16_BorderColor;
  --sapShell_Category_16_TextColor: @sapShell_Category_16_TextColor;
  --sapShell_Category_16_TextShadow: @sapShell_Category_16_TextShadow;
  --sapShell_Space_S: @sapShell_Space_S;
  --sapShell_Space_M: @sapShell_Space_M;
  --sapShell_Space_L: @sapShell_Space_L;
  --sapShell_Space_XL: @sapShell_Space_XL;
  --sapShell_Gap_S: @sapShell_Gap_S;
  --sapShell_Gap_M: @sapShell_Gap_M;
  --sapShell_Gap_L: @sapShell_Gap_L;
  --sapShell_Gap_XL: @sapShell_Gap_XL;
  --sapShell_GroupGap_S: @sapShell_GroupGap_S;
  --sapShell_GroupGap_M: @sapShell_GroupGap_M;
  --sapShell_GroupGap_L: @sapShell_GroupGap_L;
  --sapShell_GroupGap_XL: @sapShell_GroupGap_XL;
  --sapAssistant_Color1: @sapAssistant_Color1;
  --sapAssistant_Color2: @sapAssistant_Color2;
  --sapAssistant_BackgroundGradient: @sapAssistant_BackgroundGradient;
  --sapAssistant_Background: @sapAssistant_Background;
  --sapAssistant_BorderColor: @sapAssistant_BorderColor;
  --sapAssistant_TextColor: @sapAssistant_TextColor;
  --sapAssistant_Hover_Background: @sapAssistant_Hover_Background;
  --sapAssistant_Hover_BorderColor: @sapAssistant_Hover_BorderColor;
  --sapAssistant_Hover_TextColor: @sapAssistant_Hover_TextColor;
  --sapAssistant_Active_Background: @sapAssistant_Active_Background;
  --sapAssistant_Active_BorderColor: @sapAssistant_Active_BorderColor;
  --sapAssistant_Active_TextColor: @sapAssistant_Active_TextColor;
  --sapAssistant_Question_Background: @sapAssistant_Question_Background;
  --sapAssistant_Question_BorderColor: @sapAssistant_Question_BorderColor;
  --sapAssistant_Question_TextColor: @sapAssistant_Question_TextColor;
  --sapAssistant_Answer_Background: @sapAssistant_Answer_Background;
  --sapAssistant_Answer_BorderColor: @sapAssistant_Answer_BorderColor;
  --sapAssistant_Answer_TextColor: @sapAssistant_Answer_TextColor;
  --sapAvatar_1_Background: @sapAvatar_1_Background;
  --sapAvatar_1_BorderColor: @sapAvatar_1_BorderColor;
  --sapAvatar_1_TextColor: @sapAvatar_1_TextColor;
  --sapAvatar_1_Hover_Background: @sapAvatar_1_Hover_Background;
  --sapAvatar_2_Background: @sapAvatar_2_Background;
  --sapAvatar_2_BorderColor: @sapAvatar_2_BorderColor;
  --sapAvatar_2_TextColor: @sapAvatar_2_TextColor;
  --sapAvatar_2_Hover_Background: @sapAvatar_2_Hover_Background;
  --sapAvatar_3_Background: @sapAvatar_3_Background;
  --sapAvatar_3_BorderColor: @sapAvatar_3_BorderColor;
  --sapAvatar_3_TextColor: @sapAvatar_3_TextColor;
  --sapAvatar_3_Hover_Background: @sapAvatar_3_Hover_Background;
  --sapAvatar_4_Background: @sapAvatar_4_Background;
  --sapAvatar_4_BorderColor: @sapAvatar_4_BorderColor;
  --sapAvatar_4_TextColor: @sapAvatar_4_TextColor;
  --sapAvatar_4_Hover_Background: @sapAvatar_4_Hover_Background;
  --sapAvatar_5_Background: @sapAvatar_5_Background;
  --sapAvatar_5_BorderColor: @sapAvatar_5_BorderColor;
  --sapAvatar_5_TextColor: @sapAvatar_5_TextColor;
  --sapAvatar_5_Hover_Background: @sapAvatar_5_Hover_Background;
  --sapAvatar_6_Background: @sapAvatar_6_Background;
  --sapAvatar_6_BorderColor: @sapAvatar_6_BorderColor;
  --sapAvatar_6_TextColor: @sapAvatar_6_TextColor;
  --sapAvatar_6_Hover_Background: @sapAvatar_6_Hover_Background;
  --sapAvatar_7_Background: @sapAvatar_7_Background;
  --sapAvatar_7_BorderColor: @sapAvatar_7_BorderColor;
  --sapAvatar_7_TextColor: @sapAvatar_7_TextColor;
  --sapAvatar_7_Hover_Background: @sapAvatar_7_Hover_Background;
  --sapAvatar_8_Background: @sapAvatar_8_Background;
  --sapAvatar_8_BorderColor: @sapAvatar_8_BorderColor;
  --sapAvatar_8_TextColor: @sapAvatar_8_TextColor;
  --sapAvatar_8_Hover_Background: @sapAvatar_8_Hover_Background;
  --sapAvatar_9_Background: @sapAvatar_9_Background;
  --sapAvatar_9_BorderColor: @sapAvatar_9_BorderColor;
  --sapAvatar_9_TextColor: @sapAvatar_9_TextColor;
  --sapAvatar_9_Hover_Background: @sapAvatar_9_Hover_Background;
  --sapAvatar_10_Background: @sapAvatar_10_Background;
  --sapAvatar_10_BorderColor: @sapAvatar_10_BorderColor;
  --sapAvatar_10_TextColor: @sapAvatar_10_TextColor;
  --sapAvatar_10_Hover_Background: @sapAvatar_10_Hover_Background;
  --sapAvatar_Lite_BorderColor: @sapAvatar_Lite_BorderColor;
  --sapAvatar_Lite_Background: @sapAvatar_Lite_Background;
  --sapAvatar_Hover_BorderColor: @sapAvatar_Hover_BorderColor;
  --sapButton_Background: @sapButton_Background;
  --sapButton_BorderColor: @sapButton_BorderColor;
  --sapButton_BorderWidth: @sapButton_BorderWidth;
  --sapButton_BorderCornerRadius: @sapButton_BorderCornerRadius;
  --sapButton_TextColor: @sapButton_TextColor;
  --sapButton_FontFamily: @sapButton_FontFamily;
  --sapButton_Hover_Background: @sapButton_Hover_Background;
  --sapButton_Hover_BorderColor: @sapButton_Hover_BorderColor;
  --sapButton_Hover_TextColor: @sapButton_Hover_TextColor;
  --sapButton_IconColor: @sapButton_IconColor;
  --sapButton_Active_Background: @sapButton_Active_Background;
  --sapButton_Active_BorderColor: @sapButton_Active_BorderColor;
  --sapButton_Active_TextColor: @sapButton_Active_TextColor;
  --sapButton_Emphasized_Background: @sapButton_Emphasized_Background;
  --sapButton_Emphasized_BorderColor: @sapButton_Emphasized_BorderColor;
  --sapButton_Emphasized_BorderWidth: @sapButton_Emphasized_BorderWidth;
  --sapButton_Emphasized_TextColor: @sapButton_Emphasized_TextColor;
  --sapButton_Emphasized_FontFamily: @sapButton_Emphasized_FontFamily;
  --sapButton_Emphasized_Hover_Background: @sapButton_Emphasized_Hover_Background;
  --sapButton_Emphasized_Hover_BorderColor: @sapButton_Emphasized_Hover_BorderColor;
  --sapButton_Emphasized_Hover_TextColor: @sapButton_Emphasized_Hover_TextColor;
  --sapButton_Emphasized_Active_Background: @sapButton_Emphasized_Active_Background;
  --sapButton_Emphasized_Active_BorderColor: @sapButton_Emphasized_Active_BorderColor;
  --sapButton_Emphasized_Active_TextColor: @sapButton_Emphasized_Active_TextColor;
  --sapButton_Emphasized_TextShadow: @sapButton_Emphasized_TextShadow;
  --sapButton_Emphasized_FontWeight: @sapButton_Emphasized_FontWeight;
  --sapButton_Reject_Background: @sapButton_Reject_Background;
  --sapButton_Reject_BorderColor: @sapButton_Reject_BorderColor;
  --sapButton_Reject_TextColor: @sapButton_Reject_TextColor;
  --sapButton_Reject_Hover_Background: @sapButton_Reject_Hover_Background;
  --sapButton_Reject_Hover_BorderColor: @sapButton_Reject_Hover_BorderColor;
  --sapButton_Reject_Hover_TextColor: @sapButton_Reject_Hover_TextColor;
  --sapButton_Reject_Active_Background: @sapButton_Reject_Active_Background;
  --sapButton_Reject_Active_BorderColor: @sapButton_Reject_Active_BorderColor;
  --sapButton_Reject_Active_TextColor: @sapButton_Reject_Active_TextColor;
  --sapButton_Reject_Selected_Background: @sapButton_Reject_Selected_Background;
  --sapButton_Reject_Selected_BorderColor: @sapButton_Reject_Selected_BorderColor;
  --sapButton_Reject_Selected_TextColor: @sapButton_Reject_Selected_TextColor;
  --sapButton_Reject_Selected_Hover_Background: @sapButton_Reject_Selected_Hover_Background;
  --sapButton_Reject_Selected_Hover_BorderColor: @sapButton_Reject_Selected_Hover_BorderColor;
  --sapButton_Accept_Background: @sapButton_Accept_Background;
  --sapButton_Accept_BorderColor: @sapButton_Accept_BorderColor;
  --sapButton_Accept_TextColor: @sapButton_Accept_TextColor;
  --sapButton_Accept_Hover_Background: @sapButton_Accept_Hover_Background;
  --sapButton_Accept_Hover_BorderColor: @sapButton_Accept_Hover_BorderColor;
  --sapButton_Accept_Hover_TextColor: @sapButton_Accept_Hover_TextColor;
  --sapButton_Accept_Active_Background: @sapButton_Accept_Active_Background;
  --sapButton_Accept_Active_BorderColor: @sapButton_Accept_Active_BorderColor;
  --sapButton_Accept_Active_TextColor: @sapButton_Accept_Active_TextColor;
  --sapButton_Accept_Selected_Background: @sapButton_Accept_Selected_Background;
  --sapButton_Accept_Selected_BorderColor: @sapButton_Accept_Selected_BorderColor;
  --sapButton_Accept_Selected_TextColor: @sapButton_Accept_Selected_TextColor;
  --sapButton_Accept_Selected_Hover_Background: @sapButton_Accept_Selected_Hover_Background;
  --sapButton_Accept_Selected_Hover_BorderColor: @sapButton_Accept_Selected_Hover_BorderColor;
  --sapButton_Lite_Background: @sapButton_Lite_Background;
  --sapButton_Lite_BorderColor: @sapButton_Lite_BorderColor;
  --sapButton_Lite_TextColor: @sapButton_Lite_TextColor;
  --sapButton_Lite_Hover_Background: @sapButton_Lite_Hover_Background;
  --sapButton_Lite_Hover_BorderColor: @sapButton_Lite_Hover_BorderColor;
  --sapButton_Lite_Hover_TextColor: @sapButton_Lite_Hover_TextColor;
  --sapButton_Lite_Active_Background: @sapButton_Lite_Active_Background;
  --sapButton_Lite_Active_BorderColor: @sapButton_Lite_Active_BorderColor;
  --sapButton_Selected_Background: @sapButton_Selected_Background;
  --sapButton_Selected_BorderColor: @sapButton_Selected_BorderColor;
  --sapButton_Selected_TextColor: @sapButton_Selected_TextColor;
  --sapButton_Selected_Hover_Background: @sapButton_Selected_Hover_Background;
  --sapButton_Selected_Hover_BorderColor: @sapButton_Selected_Hover_BorderColor;
  --sapButton_Attention_Background: @sapButton_Attention_Background;
  --sapButton_Attention_BorderColor: @sapButton_Attention_BorderColor;
  --sapButton_Attention_TextColor: @sapButton_Attention_TextColor;
  --sapButton_Attention_Hover_Background: @sapButton_Attention_Hover_Background;
  --sapButton_Attention_Hover_BorderColor: @sapButton_Attention_Hover_BorderColor;
  --sapButton_Attention_Hover_TextColor: @sapButton_Attention_Hover_TextColor;
  --sapButton_Attention_Active_Background: @sapButton_Attention_Active_Background;
  --sapButton_Attention_Active_BorderColor: @sapButton_Attention_Active_BorderColor;
  --sapButton_Attention_Active_TextColor: @sapButton_Attention_Active_TextColor;
  --sapButton_Attention_Selected_Background: @sapButton_Attention_Selected_Background;
  --sapButton_Attention_Selected_BorderColor: @sapButton_Attention_Selected_BorderColor;
  --sapButton_Attention_Selected_TextColor: @sapButton_Attention_Selected_TextColor;
  --sapButton_Attention_Selected_Hover_Background: @sapButton_Attention_Selected_Hover_Background;
  --sapButton_Attention_Selected_Hover_BorderColor: @sapButton_Attention_Selected_Hover_BorderColor;
  --sapButton_Negative_Background: @sapButton_Negative_Background;
  --sapButton_Negative_BorderColor: @sapButton_Negative_BorderColor;
  --sapButton_Negative_TextColor: @sapButton_Negative_TextColor;
  --sapButton_Negative_Hover_Background: @sapButton_Negative_Hover_Background;
  --sapButton_Negative_Hover_BorderColor: @sapButton_Negative_Hover_BorderColor;
  --sapButton_Negative_Hover_TextColor: @sapButton_Negative_Hover_TextColor;
  --sapButton_Negative_Active_Background: @sapButton_Negative_Active_Background;
  --sapButton_Negative_Active_BorderColor: @sapButton_Negative_Active_BorderColor;
  --sapButton_Negative_Active_TextColor: @sapButton_Negative_Active_TextColor;
  --sapButton_Critical_Background: @sapButton_Critical_Background;
  --sapButton_Critical_BorderColor: @sapButton_Critical_BorderColor;
  --sapButton_Critical_TextColor: @sapButton_Critical_TextColor;
  --sapButton_Critical_Hover_Background: @sapButton_Critical_Hover_Background;
  --sapButton_Critical_Hover_BorderColor: @sapButton_Critical_Hover_BorderColor;
  --sapButton_Critical_Hover_TextColor: @sapButton_Critical_Hover_TextColor;
  --sapButton_Critical_Active_Background: @sapButton_Critical_Active_Background;
  --sapButton_Critical_Active_BorderColor: @sapButton_Critical_Active_BorderColor;
  --sapButton_Critical_Active_TextColor: @sapButton_Critical_Active_TextColor;
  --sapButton_Success_Background: @sapButton_Success_Background;
  --sapButton_Success_BorderColor: @sapButton_Success_BorderColor;
  --sapButton_Success_TextColor: @sapButton_Success_TextColor;
  --sapButton_Success_Hover_Background: @sapButton_Success_Hover_Background;
  --sapButton_Success_Hover_BorderColor: @sapButton_Success_Hover_BorderColor;
  --sapButton_Success_Hover_TextColor: @sapButton_Success_Hover_TextColor;
  --sapButton_Success_Active_Background: @sapButton_Success_Active_Background;
  --sapButton_Success_Active_BorderColor: @sapButton_Success_Active_BorderColor;
  --sapButton_Success_Active_TextColor: @sapButton_Success_Active_TextColor;
  --sapButton_Information_Background: @sapButton_Information_Background;
  --sapButton_Information_BorderColor: @sapButton_Information_BorderColor;
  --sapButton_Information_TextColor: @sapButton_Information_TextColor;
  --sapButton_Information_Hover_Background: @sapButton_Information_Hover_Background;
  --sapButton_Information_Hover_BorderColor: @sapButton_Information_Hover_BorderColor;
  --sapButton_Information_Hover_TextColor: @sapButton_Information_Hover_TextColor;
  --sapButton_Information_Active_Background: @sapButton_Information_Active_Background;
  --sapButton_Information_Active_BorderColor: @sapButton_Information_Active_BorderColor;
  --sapButton_Information_Active_TextColor: @sapButton_Information_Active_TextColor;
  --sapButton_Neutral_Background: @sapButton_Neutral_Background;
  --sapButton_Neutral_BorderColor: @sapButton_Neutral_BorderColor;
  --sapButton_Neutral_TextColor: @sapButton_Neutral_TextColor;
  --sapButton_Neutral_Hover_Background: @sapButton_Neutral_Hover_Background;
  --sapButton_Neutral_Hover_BorderColor: @sapButton_Neutral_Hover_BorderColor;
  --sapButton_Neutral_Hover_TextColor: @sapButton_Neutral_Hover_TextColor;
  --sapButton_Neutral_Active_Background: @sapButton_Neutral_Active_Background;
  --sapButton_Neutral_Active_BorderColor: @sapButton_Neutral_Active_BorderColor;
  --sapButton_Neutral_Active_TextColor: @sapButton_Neutral_Active_TextColor;
  --sapButton_Track_Background: @sapButton_Track_Background;
  --sapButton_Track_BorderColor: @sapButton_Track_BorderColor;
  --sapButton_Track_TextColor: @sapButton_Track_TextColor;
  --sapButton_Track_Hover_Background: @sapButton_Track_Hover_Background;
  --sapButton_Track_Hover_BorderColor: @sapButton_Track_Hover_BorderColor;
  --sapButton_Track_Selected_Background: @sapButton_Track_Selected_Background;
  --sapButton_Track_Selected_BorderColor: @sapButton_Track_Selected_BorderColor;
  --sapButton_Track_Selected_TextColor: @sapButton_Track_Selected_TextColor;
  --sapButton_Track_Selected_Hover_Background: @sapButton_Track_Selected_Hover_Background;
  --sapButton_Track_Selected_Hover_BorderColor: @sapButton_Track_Selected_Hover_BorderColor;
  --sapButton_Handle_Background: @sapButton_Handle_Background;
  --sapButton_Handle_BorderColor: @sapButton_Handle_BorderColor;
  --sapButton_Handle_TextColor: @sapButton_Handle_TextColor;
  --sapButton_Handle_Hover_Background: @sapButton_Handle_Hover_Background;
  --sapButton_Handle_Hover_BorderColor: @sapButton_Handle_Hover_BorderColor;
  --sapButton_Handle_Selected_Background: @sapButton_Handle_Selected_Background;
  --sapButton_Handle_Selected_BorderColor: @sapButton_Handle_Selected_BorderColor;
  --sapButton_Handle_Selected_TextColor: @sapButton_Handle_Selected_TextColor;
  --sapButton_Handle_Selected_Hover_Background: @sapButton_Handle_Selected_Hover_Background;
  --sapButton_Handle_Selected_Hover_BorderColor: @sapButton_Handle_Selected_Hover_BorderColor;
  --sapButton_Track_Negative_Background: @sapButton_Track_Negative_Background;
  --sapButton_Track_Negative_BorderColor: @sapButton_Track_Negative_BorderColor;
  --sapButton_Track_Negative_TextColor: @sapButton_Track_Negative_TextColor;
  --sapButton_Track_Negative_Hover_Background: @sapButton_Track_Negative_Hover_Background;
  --sapButton_Track_Negative_Hover_BorderColor: @sapButton_Track_Negative_Hover_BorderColor;
  --sapButton_Handle_Negative_Background: @sapButton_Handle_Negative_Background;
  --sapButton_Handle_Negative_BorderColor: @sapButton_Handle_Negative_BorderColor;
  --sapButton_Handle_Negative_TextColor: @sapButton_Handle_Negative_TextColor;
  --sapButton_Handle_Negative_Hover_Background: @sapButton_Handle_Negative_Hover_Background;
  --sapButton_Handle_Negative_Hover_BorderColor: @sapButton_Handle_Negative_Hover_BorderColor;
  --sapButton_Track_Positive_Background: @sapButton_Track_Positive_Background;
  --sapButton_Track_Positive_BorderColor: @sapButton_Track_Positive_BorderColor;
  --sapButton_Track_Positive_TextColor: @sapButton_Track_Positive_TextColor;
  --sapButton_Track_Positive_Hover_Background: @sapButton_Track_Positive_Hover_Background;
  --sapButton_Track_Positive_Hover_BorderColor: @sapButton_Track_Positive_Hover_BorderColor;
  --sapButton_Handle_Positive_Background: @sapButton_Handle_Positive_Background;
  --sapButton_Handle_Positive_BorderColor: @sapButton_Handle_Positive_BorderColor;
  --sapButton_Handle_Positive_TextColor: @sapButton_Handle_Positive_TextColor;
  --sapButton_Handle_Positive_Hover_Background: @sapButton_Handle_Positive_Hover_Background;
  --sapButton_Handle_Positive_Hover_BorderColor: @sapButton_Handle_Positive_Hover_BorderColor;
  --sapButton_TokenBackground: @sapButton_TokenBackground;
  --sapButton_TokenBorderColor: @sapButton_TokenBorderColor;
  --sapButton_TokenBorderCornerRadius: @sapButton_TokenBorderCornerRadius;
  --sapButton_Selected_TokenBorderWidth: @sapButton_Selected_TokenBorderWidth;
  --sapButton_ReadOnly_TokenBackground: @sapButton_ReadOnly_TokenBackground;
  --sapButton_Segment_BorderCornerRadius: @sapButton_Segment_BorderCornerRadius;
  --sapField_Background: @sapField_Background;
  --sapField_BackgroundStyle: @sapField_BackgroundStyle;
  --sapField_TextColor: @sapField_TextColor;
  --sapField_PlaceholderTextColor: @sapField_PlaceholderTextColor;
  --sapField_BorderColor: @sapField_BorderColor;
  --sapField_HelpBackground: @sapField_HelpBackground;
  --sapField_BorderWidth: @sapField_BorderWidth;
  --sapField_BorderStyle: @sapField_BorderStyle;
  --sapField_BorderCornerRadius: @sapField_BorderCornerRadius;
  --sapField_Shadow: @sapField_Shadow;
  --sapField_Hover_Background: @sapField_Hover_Background;
  --sapField_Hover_BackgroundStyle: @sapField_Hover_BackgroundStyle;
  --sapField_Hover_BorderColor: @sapField_Hover_BorderColor;
  --sapField_Hover_HelpBackground: @sapField_Hover_HelpBackground;
  --sapField_Hover_Shadow: @sapField_Hover_Shadow;
  --sapField_Hover_InvalidShadow: @sapField_Hover_InvalidShadow;
  --sapField_Hover_WarningShadow: @sapField_Hover_WarningShadow;
  --sapField_Hover_SuccessShadow: @sapField_Hover_SuccessShadow;
  --sapField_Hover_InformationShadow: @sapField_Hover_InformationShadow;
  --sapField_Active_BorderColor: @sapField_Active_BorderColor;
  --sapField_Focus_Background: @sapField_Focus_Background;
  --sapField_Focus_BorderColor: @sapField_Focus_BorderColor;
  --sapField_Focus_HelpBackground: @sapField_Focus_HelpBackground;
  --sapField_ReadOnly_Background: @sapField_ReadOnly_Background;
  --sapField_ReadOnly_BackgroundStyle: @sapField_ReadOnly_BackgroundStyle;
  --sapField_ReadOnly_BorderColor: @sapField_ReadOnly_BorderColor;
  --sapField_ReadOnly_BorderStyle: @sapField_ReadOnly_BorderStyle;
  --sapField_ReadOnly_HelpBackground: @sapField_ReadOnly_HelpBackground;
  --sapField_RequiredColor: @sapField_RequiredColor;
  --sapField_InvalidColor: @sapField_InvalidColor;
  --sapField_InvalidBackground: @sapField_InvalidBackground;
  --sapField_InvalidBackgroundStyle: @sapField_InvalidBackgroundStyle;
  --sapField_InvalidBorderWidth: @sapField_InvalidBorderWidth;
  --sapField_InvalidBorderStyle: @sapField_InvalidBorderStyle;
  --sapField_InvalidShadow: @sapField_InvalidShadow;
  --sapField_WarningColor: @sapField_WarningColor;
  --sapField_WarningBackground: @sapField_WarningBackground;
  --sapField_WarningBackgroundStyle: @sapField_WarningBackgroundStyle;
  --sapField_WarningBorderWidth: @sapField_WarningBorderWidth;
  --sapField_WarningBorderStyle: @sapField_WarningBorderStyle;
  --sapField_WarningShadow: @sapField_WarningShadow;
  --sapField_SuccessColor: @sapField_SuccessColor;
  --sapField_SuccessBackground: @sapField_SuccessBackground;
  --sapField_SuccessBackgroundStyle: @sapField_SuccessBackgroundStyle;
  --sapField_SuccessBorderWidth: @sapField_SuccessBorderWidth;
  --sapField_SuccessBorderStyle: @sapField_SuccessBorderStyle;
  --sapField_SuccessShadow: @sapField_SuccessShadow;
  --sapField_InformationColor: @sapField_InformationColor;
  --sapField_InformationBackground: @sapField_InformationBackground;
  --sapField_InformationBackgroundStyle: @sapField_InformationBackgroundStyle;
  --sapField_InformationBorderWidth: @sapField_InformationBorderWidth;
  --sapField_InformationBorderStyle: @sapField_InformationBorderStyle;
  --sapField_InformationShadow: @sapField_InformationShadow;
  --sapField_Selector_Hover_Background: @sapField_Selector_Hover_Background;
  --sapField_Selector_Hover_InvalidBackground: @sapField_Selector_Hover_InvalidBackground;
  --sapField_Selector_Hover_WarningBackground: @sapField_Selector_Hover_WarningBackground;
  --sapField_Selector_Hover_SuccessBackground: @sapField_Selector_Hover_SuccessBackground;
  --sapField_Selector_Hover_InformationBackground: @sapField_Selector_Hover_InformationBackground;
  --sapField_Picker_BorderColor: @sapField_Picker_BorderColor;
  --sapField_Picker_BorderWidth: @sapField_Picker_BorderWidth;
  --sapField_Selector_BorderStyle: @sapField_Selector_BorderStyle;
  --sapField_Selector_ReadOnly_BorderStyle: @sapField_Selector_ReadOnly_BorderStyle;
  --sapField_Selector_InvalidBorderStyle: @sapField_Selector_InvalidBorderStyle;
  --sapField_Selector_WarningBorderStyle: @sapField_Selector_WarningBorderStyle;
  --sapField_Selector_SuccessBorderStyle: @sapField_Selector_SuccessBorderStyle;
  --sapField_Selector_InformationBorderStyle: @sapField_Selector_InformationBorderStyle;
  --sapGroup_TitleBorderWidth: @sapGroup_TitleBorderWidth;
  --sapGroup_TitleBackground: @sapGroup_TitleBackground;
  --sapGroup_TitleBorderColor: @sapGroup_TitleBorderColor;
  --sapGroup_TitleTextColor: @sapGroup_TitleTextColor;
  --sapGroup_Title_FontSize: @sapGroup_Title_FontSize;
  --sapGroup_ContentBackground: @sapGroup_ContentBackground;
  --sapGroup_ContentBorderColor: @sapGroup_ContentBorderColor;
  --sapGroup_BorderWidth: @sapGroup_BorderWidth;
  --sapGroup_BorderCornerRadius: @sapGroup_BorderCornerRadius;
  --sapGroup_FooterBackground: @sapGroup_FooterBackground;
  --sapToolbar_Background: @sapToolbar_Background;
  --sapToolbar_SeparatorColor: @sapToolbar_SeparatorColor;
  --sapList_HeaderBackground: @sapList_HeaderBackground;
  --sapList_HeaderBorderColor: @sapList_HeaderBorderColor;
  --sapList_HeaderTextColor: @sapList_HeaderTextColor;
  --sapList_BorderColor: @sapList_BorderColor;
  --sapList_BorderWidth: @sapList_BorderWidth;
  --sapList_TextColor: @sapList_TextColor;
  --sapList_Active_TextColor: @sapList_Active_TextColor;
  --sapList_Active_Background: @sapList_Active_Background;
  --sapList_SelectionBackgroundColor: @sapList_SelectionBackgroundColor;
  --sapList_SelectionBorderColor: @sapList_SelectionBorderColor;
  --sapList_Hover_SelectionBackground: @sapList_Hover_SelectionBackground;
  --sapList_Background: @sapList_Background;
  --sapList_Hover_Background: @sapList_Hover_Background;
  --sapList_AlternatingBackground: @sapList_AlternatingBackground;
  --sapList_GroupHeaderBackground: @sapList_GroupHeaderBackground;
  --sapList_GroupHeaderBorderColor: @sapList_GroupHeaderBorderColor;
  --sapList_GroupHeaderTextColor: @sapList_GroupHeaderTextColor;
  --sapList_TableGroupHeaderBackground: @sapList_TableGroupHeaderBackground;
  --sapList_TableGroupHeaderBorderColor: @sapList_TableGroupHeaderBorderColor;
  --sapList_TableGroupHeaderTextColor: @sapList_TableGroupHeaderTextColor;
  --sapList_FooterBackground: @sapList_FooterBackground;
  --sapList_FooterTextColor: @sapList_FooterTextColor;
  --sapList_TableFooterBorder: @sapList_TableFooterBorder;
  --sapList_TableFixedBorderColor: @sapList_TableFixedBorderColor;
  --sapList_TableFixedColumnBorderWidth: @sapList_TableFixedColumnBorderWidth;
  --sapList_TableFixedRowBorderWidth: @sapList_TableFixedRowBorderWidth;
  --sapMessage_BorderWidth: @sapMessage_BorderWidth;
  --sapMessage_ErrorBorderColor: @sapMessage_ErrorBorderColor;
  --sapMessage_WarningBorderColor: @sapMessage_WarningBorderColor;
  --sapMessage_SuccessBorderColor: @sapMessage_SuccessBorderColor;
  --sapMessage_InformationBorderColor: @sapMessage_InformationBorderColor;
  --sapMessage_Button_Hover_Background: @sapMessage_Button_Hover_Background;
  --sapPopover_BorderCornerRadius: @sapPopover_BorderCornerRadius;
  --sapProgress_Background: @sapProgress_Background;
  --sapProgress_BorderColor: @sapProgress_BorderColor;
  --sapProgress_TextColor: @sapProgress_TextColor;
  --sapProgress_FontSize: @sapProgress_FontSize;
  --sapProgress_NegativeBackground: @sapProgress_NegativeBackground;
  --sapProgress_NegativeBorderColor: @sapProgress_NegativeBorderColor;
  --sapProgress_NegativeTextColor: @sapProgress_NegativeTextColor;
  --sapProgress_CriticalBackground: @sapProgress_CriticalBackground;
  --sapProgress_CriticalBorderColor: @sapProgress_CriticalBorderColor;
  --sapProgress_CriticalTextColor: @sapProgress_CriticalTextColor;
  --sapProgress_PositiveBackground: @sapProgress_PositiveBackground;
  --sapProgress_PositiveBorderColor: @sapProgress_PositiveBorderColor;
  --sapProgress_PositiveTextColor: @sapProgress_PositiveTextColor;
  --sapProgress_InformationBackground: @sapProgress_InformationBackground;
  --sapProgress_InformationBorderColor: @sapProgress_InformationBorderColor;
  --sapProgress_InformationTextColor: @sapProgress_InformationTextColor;
  --sapProgress_Value_Background: @sapProgress_Value_Background;
  --sapProgress_Value_BorderColor: @sapProgress_Value_BorderColor;
  --sapProgress_Value_TextColor: @sapProgress_Value_TextColor;
  --sapProgress_Value_NegativeBackground: @sapProgress_Value_NegativeBackground;
  --sapProgress_Value_NegativeBorderColor: @sapProgress_Value_NegativeBorderColor;
  --sapProgress_Value_NegativeTextColor: @sapProgress_Value_NegativeTextColor;
  --sapProgress_Value_CriticalBackground: @sapProgress_Value_CriticalBackground;
  --sapProgress_Value_CriticalBorderColor: @sapProgress_Value_CriticalBorderColor;
  --sapProgress_Value_CriticalTextColor: @sapProgress_Value_CriticalTextColor;
  --sapProgress_Value_PositiveBackground: @sapProgress_Value_PositiveBackground;
  --sapProgress_Value_PositiveBorderColor: @sapProgress_Value_PositiveBorderColor;
  --sapProgress_Value_PositiveTextColor: @sapProgress_Value_PositiveTextColor;
  --sapProgress_Value_InformationBackground: @sapProgress_Value_InformationBackground;
  --sapProgress_Value_InformationBorderColor: @sapProgress_Value_InformationBorderColor;
  --sapProgress_Value_InformationTextColor: @sapProgress_Value_InformationTextColor;
  --sapScrollBar_FaceColor: @sapScrollBar_FaceColor;
  --sapScrollBar_TrackColor: @sapScrollBar_TrackColor;
  --sapScrollBar_BorderColor: @sapScrollBar_BorderColor;
  --sapScrollBar_SymbolColor: @sapScrollBar_SymbolColor;
  --sapScrollBar_Dimension: @sapScrollBar_Dimension;
  --sapScrollBar_Hover_FaceColor: @sapScrollBar_Hover_FaceColor;
  --sapSlider_Background: @sapSlider_Background;
  --sapSlider_BorderColor: @sapSlider_BorderColor;
  --sapSlider_Selected_Background: @sapSlider_Selected_Background;
  --sapSlider_Selected_BorderColor: @sapSlider_Selected_BorderColor;
  --sapSlider_Selected_Dimension: @sapSlider_Selected_Dimension;
  --sapSlider_HandleBackground: @sapSlider_HandleBackground;
  --sapSlider_HandleBorderColor: @sapSlider_HandleBorderColor;
  --sapSlider_RangeHandleBackground: @sapSlider_RangeHandleBackground;
  --sapSlider_Hover_HandleBackground: @sapSlider_Hover_HandleBackground;
  --sapSlider_Hover_HandleBorderColor: @sapSlider_Hover_HandleBorderColor;
  --sapSlider_Hover_RangeHandleBackground: @sapSlider_Hover_RangeHandleBackground;
  --sapSlider_Active_HandleBackground: @sapSlider_Active_HandleBackground;
  --sapSlider_Active_HandleBorderColor: @sapSlider_Active_HandleBorderColor;
  --sapSlider_Active_RangeHandleBackground: @sapSlider_Active_RangeHandleBackground;
  --sapPageHeader_Background: @sapPageHeader_Background;
  --sapPageHeader_BorderColor: @sapPageHeader_BorderColor;
  --sapPageHeader_TextColor: @sapPageHeader_TextColor;
  --sapPageFooter_Background: @sapPageFooter_Background;
  --sapPageFooter_BorderColor: @sapPageFooter_BorderColor;
  --sapPageFooter_TextColor: @sapPageFooter_TextColor;
  --sapInfobar_Background: @sapInfobar_Background;
  --sapInfobar_Hover_Background: @sapInfobar_Hover_Background;
  --sapInfobar_Active_Background: @sapInfobar_Active_Background;
  --sapInfobar_NonInteractive_Background: @sapInfobar_NonInteractive_Background;
  --sapInfobar_TextColor: @sapInfobar_TextColor;
  --sapObjectHeader_Background: @sapObjectHeader_Background;
  --sapObjectHeader_Hover_Background: @sapObjectHeader_Hover_Background;
  --sapObjectHeader_BorderColor: @sapObjectHeader_BorderColor;
  --sapObjectHeader_Title_TextColor: @sapObjectHeader_Title_TextColor;
  --sapObjectHeader_Title_FontSize: @sapObjectHeader_Title_FontSize;
  --sapObjectHeader_Title_SnappedFontSize: @sapObjectHeader_Title_SnappedFontSize;
  --sapObjectHeader_Title_FontFamily: @sapObjectHeader_Title_FontFamily;
  --sapObjectHeader_Subtitle_TextColor: @sapObjectHeader_Subtitle_TextColor;
  --sapBlockLayer_Background: @sapBlockLayer_Background;
  --sapBlockLayer_Opacity: @sapBlockLayer_Opacity;
  --sapTab_TextColor: @sapTab_TextColor;
  --sapTab_ForegroundColor: @sapTab_ForegroundColor;
  --sapTab_IconColor: @sapTab_IconColor;
  --sapTab_Background: @sapTab_Background;
  --sapTab_Selected_TextColor: @sapTab_Selected_TextColor;
  --sapTab_Selected_IconColor: @sapTab_Selected_IconColor;
  --sapTab_Selected_Background: @sapTab_Selected_Background;
  --sapTab_Selected_Indicator_Dimension: @sapTab_Selected_Indicator_Dimension;
  --sapTab_Positive_TextColor: @sapTab_Positive_TextColor;
  --sapTab_Positive_ForegroundColor: @sapTab_Positive_ForegroundColor;
  --sapTab_Positive_IconColor: @sapTab_Positive_IconColor;
  --sapTab_Positive_Selected_TextColor: @sapTab_Positive_Selected_TextColor;
  --sapTab_Positive_Selected_IconColor: @sapTab_Positive_Selected_IconColor;
  --sapTab_Positive_Selected_Background: @sapTab_Positive_Selected_Background;
  --sapTab_Negative_TextColor: @sapTab_Negative_TextColor;
  --sapTab_Negative_ForegroundColor: @sapTab_Negative_ForegroundColor;
  --sapTab_Negative_IconColor: @sapTab_Negative_IconColor;
  --sapTab_Negative_Selected_TextColor: @sapTab_Negative_Selected_TextColor;
  --sapTab_Negative_Selected_IconColor: @sapTab_Negative_Selected_IconColor;
  --sapTab_Negative_Selected_Background: @sapTab_Negative_Selected_Background;
  --sapTab_Critical_TextColor: @sapTab_Critical_TextColor;
  --sapTab_Critical_ForegroundColor: @sapTab_Critical_ForegroundColor;
  --sapTab_Critical_IconColor: @sapTab_Critical_IconColor;
  --sapTab_Critical_Selected_TextColor: @sapTab_Critical_Selected_TextColor;
  --sapTab_Critical_Selected_IconColor: @sapTab_Critical_Selected_IconColor;
  --sapTab_Critical_Selected_Background: @sapTab_Critical_Selected_Background;
  --sapTab_Neutral_TextColor: @sapTab_Neutral_TextColor;
  --sapTab_Neutral_ForegroundColor: @sapTab_Neutral_ForegroundColor;
  --sapTab_Neutral_IconColor: @sapTab_Neutral_IconColor;
  --sapTab_Neutral_Selected_TextColor: @sapTab_Neutral_Selected_TextColor;
  --sapTab_Neutral_Selected_IconColor: @sapTab_Neutral_Selected_IconColor;
  --sapTab_Neutral_Selected_Background: @sapTab_Neutral_Selected_Background;
  --sapTile_Background: @sapTile_Background;
  --sapTile_Hover_Background: @sapTile_Hover_Background;
  --sapTile_Active_Background: @sapTile_Active_Background;
  --sapTile_BorderColor: @sapTile_BorderColor;
  --sapTile_BorderCornerRadius: @sapTile_BorderCornerRadius;
  --sapTile_TitleTextColor: @sapTile_TitleTextColor;
  --sapTile_TextColor: @sapTile_TextColor;
  --sapTile_IconColor: @sapTile_IconColor;
  --sapTile_SeparatorColor: @sapTile_SeparatorColor;
  --sapTile_Interactive_BorderColor: @sapTile_Interactive_BorderColor;
  --sapTile_OverlayBackground: @sapTile_OverlayBackground;
  --sapTile_OverlayForegroundColor: @sapTile_OverlayForegroundColor;
  --sapTile_Hover_ContentBackground: @sapTile_Hover_ContentBackground;
  --sapTile_Active_ContentBackground: @sapTile_Active_ContentBackground;
  --sapAccentColor1: @sapAccentColor1;
  --sapAccentColor2: @sapAccentColor2;
  --sapAccentColor3: @sapAccentColor3;
  --sapAccentColor4: @sapAccentColor4;
  --sapAccentColor5: @sapAccentColor5;
  --sapAccentColor6: @sapAccentColor6;
  --sapAccentColor7: @sapAccentColor7;
  --sapAccentColor8: @sapAccentColor8;
  --sapAccentColor9: @sapAccentColor9;
  --sapAccentColor10: @sapAccentColor10;
  --sapAccentBackgroundColor1: @sapAccentBackgroundColor1;
  --sapAccentBackgroundColor2: @sapAccentBackgroundColor2;
  --sapAccentBackgroundColor3: @sapAccentBackgroundColor3;
  --sapAccentBackgroundColor4: @sapAccentBackgroundColor4;
  --sapAccentBackgroundColor5: @sapAccentBackgroundColor5;
  --sapAccentBackgroundColor6: @sapAccentBackgroundColor6;
  --sapAccentBackgroundColor7: @sapAccentBackgroundColor7;
  --sapAccentBackgroundColor8: @sapAccentBackgroundColor8;
  --sapAccentBackgroundColor9: @sapAccentBackgroundColor9;
  --sapAccentBackgroundColor10: @sapAccentBackgroundColor10;
  --sapIndicationColor_1: @sapIndicationColor_1;
  --sapIndicationColor_1_Background: @sapIndicationColor_1_Background;
  --sapIndicationColor_1_BorderColor: @sapIndicationColor_1_BorderColor;
  --sapIndicationColor_1_TextColor: @sapIndicationColor_1_TextColor;
  --sapIndicationColor_1_Hover_Background: @sapIndicationColor_1_Hover_Background;
  --sapIndicationColor_1_Active_Background: @sapIndicationColor_1_Active_Background;
  --sapIndicationColor_1_Active_BorderColor: @sapIndicationColor_1_Active_BorderColor;
  --sapIndicationColor_1_Active_TextColor: @sapIndicationColor_1_Active_TextColor;
  --sapIndicationColor_1_Selected_Background: @sapIndicationColor_1_Selected_Background;
  --sapIndicationColor_1_Selected_BorderColor: @sapIndicationColor_1_Selected_BorderColor;
  --sapIndicationColor_1_Selected_TextColor: @sapIndicationColor_1_Selected_TextColor;
  --sapIndicationColor_1b: @sapIndicationColor_1b;
  --sapIndicationColor_1b_TextColor: @sapIndicationColor_1b_TextColor;
  --sapIndicationColor_1b_Background: @sapIndicationColor_1b_Background;
  --sapIndicationColor_1b_BorderColor: @sapIndicationColor_1b_BorderColor;
  --sapIndicationColor_1b_Hover_Background: @sapIndicationColor_1b_Hover_Background;
  --sapIndicationColor_2: @sapIndicationColor_2;
  --sapIndicationColor_2_Background: @sapIndicationColor_2_Background;
  --sapIndicationColor_2_BorderColor: @sapIndicationColor_2_BorderColor;
  --sapIndicationColor_2_TextColor: @sapIndicationColor_2_TextColor;
  --sapIndicationColor_2_Hover_Background: @sapIndicationColor_2_Hover_Background;
  --sapIndicationColor_2_Active_Background: @sapIndicationColor_2_Active_Background;
  --sapIndicationColor_2_Active_BorderColor: @sapIndicationColor_2_Active_BorderColor;
  --sapIndicationColor_2_Active_TextColor: @sapIndicationColor_2_Active_TextColor;
  --sapIndicationColor_2_Selected_Background: @sapIndicationColor_2_Selected_Background;
  --sapIndicationColor_2_Selected_BorderColor: @sapIndicationColor_2_Selected_BorderColor;
  --sapIndicationColor_2_Selected_TextColor: @sapIndicationColor_2_Selected_TextColor;
  --sapIndicationColor_2b: @sapIndicationColor_2b;
  --sapIndicationColor_2b_TextColor: @sapIndicationColor_2b_TextColor;
  --sapIndicationColor_2b_Background: @sapIndicationColor_2b_Background;
  --sapIndicationColor_2b_BorderColor: @sapIndicationColor_2b_BorderColor;
  --sapIndicationColor_2b_Hover_Background: @sapIndicationColor_2b_Hover_Background;
  --sapIndicationColor_3: @sapIndicationColor_3;
  --sapIndicationColor_3_Background: @sapIndicationColor_3_Background;
  --sapIndicationColor_3_BorderColor: @sapIndicationColor_3_BorderColor;
  --sapIndicationColor_3_TextColor: @sapIndicationColor_3_TextColor;
  --sapIndicationColor_3_Hover_Background: @sapIndicationColor_3_Hover_Background;
  --sapIndicationColor_3_Active_Background: @sapIndicationColor_3_Active_Background;
  --sapIndicationColor_3_Active_BorderColor: @sapIndicationColor_3_Active_BorderColor;
  --sapIndicationColor_3_Active_TextColor: @sapIndicationColor_3_Active_TextColor;
  --sapIndicationColor_3_Selected_Background: @sapIndicationColor_3_Selected_Background;
  --sapIndicationColor_3_Selected_BorderColor: @sapIndicationColor_3_Selected_BorderColor;
  --sapIndicationColor_3_Selected_TextColor: @sapIndicationColor_3_Selected_TextColor;
  --sapIndicationColor_3b: @sapIndicationColor_3b;
  --sapIndicationColor_3b_TextColor: @sapIndicationColor_3b_TextColor;
  --sapIndicationColor_3b_Background: @sapIndicationColor_3b_Background;
  --sapIndicationColor_3b_BorderColor: @sapIndicationColor_3b_BorderColor;
  --sapIndicationColor_3b_Hover_Background: @sapIndicationColor_3b_Hover_Background;
  --sapIndicationColor_4: @sapIndicationColor_4;
  --sapIndicationColor_4_Background: @sapIndicationColor_4_Background;
  --sapIndicationColor_4_BorderColor: @sapIndicationColor_4_BorderColor;
  --sapIndicationColor_4_TextColor: @sapIndicationColor_4_TextColor;
  --sapIndicationColor_4_Hover_Background: @sapIndicationColor_4_Hover_Background;
  --sapIndicationColor_4_Active_Background: @sapIndicationColor_4_Active_Background;
  --sapIndicationColor_4_Active_BorderColor: @sapIndicationColor_4_Active_BorderColor;
  --sapIndicationColor_4_Active_TextColor: @sapIndicationColor_4_Active_TextColor;
  --sapIndicationColor_4_Selected_Background: @sapIndicationColor_4_Selected_Background;
  --sapIndicationColor_4_Selected_BorderColor: @sapIndicationColor_4_Selected_BorderColor;
  --sapIndicationColor_4_Selected_TextColor: @sapIndicationColor_4_Selected_TextColor;
  --sapIndicationColor_4b: @sapIndicationColor_4b;
  --sapIndicationColor_4b_TextColor: @sapIndicationColor_4b_TextColor;
  --sapIndicationColor_4b_Background: @sapIndicationColor_4b_Background;
  --sapIndicationColor_4b_BorderColor: @sapIndicationColor_4b_BorderColor;
  --sapIndicationColor_4b_Hover_Background: @sapIndicationColor_4b_Hover_Background;
  --sapIndicationColor_5: @sapIndicationColor_5;
  --sapIndicationColor_5_Background: @sapIndicationColor_5_Background;
  --sapIndicationColor_5_BorderColor: @sapIndicationColor_5_BorderColor;
  --sapIndicationColor_5_TextColor: @sapIndicationColor_5_TextColor;
  --sapIndicationColor_5_Hover_Background: @sapIndicationColor_5_Hover_Background;
  --sapIndicationColor_5_Active_Background: @sapIndicationColor_5_Active_Background;
  --sapIndicationColor_5_Active_BorderColor: @sapIndicationColor_5_Active_BorderColor;
  --sapIndicationColor_5_Active_TextColor: @sapIndicationColor_5_Active_TextColor;
  --sapIndicationColor_5_Selected_Background: @sapIndicationColor_5_Selected_Background;
  --sapIndicationColor_5_Selected_BorderColor: @sapIndicationColor_5_Selected_BorderColor;
  --sapIndicationColor_5_Selected_TextColor: @sapIndicationColor_5_Selected_TextColor;
  --sapIndicationColor_5b: @sapIndicationColor_5b;
  --sapIndicationColor_5b_TextColor: @sapIndicationColor_5b_TextColor;
  --sapIndicationColor_5b_Background: @sapIndicationColor_5b_Background;
  --sapIndicationColor_5b_BorderColor: @sapIndicationColor_5b_BorderColor;
  --sapIndicationColor_5b_Hover_Background: @sapIndicationColor_5b_Hover_Background;
  --sapIndicationColor_6: @sapIndicationColor_6;
  --sapIndicationColor_6_Background: @sapIndicationColor_6_Background;
  --sapIndicationColor_6_BorderColor: @sapIndicationColor_6_BorderColor;
  --sapIndicationColor_6_TextColor: @sapIndicationColor_6_TextColor;
  --sapIndicationColor_6_Hover_Background: @sapIndicationColor_6_Hover_Background;
  --sapIndicationColor_6_Active_Background: @sapIndicationColor_6_Active_Background;
  --sapIndicationColor_6_Active_BorderColor: @sapIndicationColor_6_Active_BorderColor;
  --sapIndicationColor_6_Active_TextColor: @sapIndicationColor_6_Active_TextColor;
  --sapIndicationColor_6_Selected_Background: @sapIndicationColor_6_Selected_Background;
  --sapIndicationColor_6_Selected_BorderColor: @sapIndicationColor_6_Selected_BorderColor;
  --sapIndicationColor_6_Selected_TextColor: @sapIndicationColor_6_Selected_TextColor;
  --sapIndicationColor_6b: @sapIndicationColor_6b;
  --sapIndicationColor_6b_TextColor: @sapIndicationColor_6b_TextColor;
  --sapIndicationColor_6b_Background: @sapIndicationColor_6b_Background;
  --sapIndicationColor_6b_BorderColor: @sapIndicationColor_6b_BorderColor;
  --sapIndicationColor_6b_Hover_Background: @sapIndicationColor_6b_Hover_Background;
  --sapIndicationColor_7: @sapIndicationColor_7;
  --sapIndicationColor_7_Background: @sapIndicationColor_7_Background;
  --sapIndicationColor_7_BorderColor: @sapIndicationColor_7_BorderColor;
  --sapIndicationColor_7_TextColor: @sapIndicationColor_7_TextColor;
  --sapIndicationColor_7_Hover_Background: @sapIndicationColor_7_Hover_Background;
  --sapIndicationColor_7_Active_Background: @sapIndicationColor_7_Active_Background;
  --sapIndicationColor_7_Active_BorderColor: @sapIndicationColor_7_Active_BorderColor;
  --sapIndicationColor_7_Active_TextColor: @sapIndicationColor_7_Active_TextColor;
  --sapIndicationColor_7_Selected_Background: @sapIndicationColor_7_Selected_Background;
  --sapIndicationColor_7_Selected_BorderColor: @sapIndicationColor_7_Selected_BorderColor;
  --sapIndicationColor_7_Selected_TextColor: @sapIndicationColor_7_Selected_TextColor;
  --sapIndicationColor_7b: @sapIndicationColor_7b;
  --sapIndicationColor_7b_TextColor: @sapIndicationColor_7b_TextColor;
  --sapIndicationColor_7b_Background: @sapIndicationColor_7b_Background;
  --sapIndicationColor_7b_BorderColor: @sapIndicationColor_7b_BorderColor;
  --sapIndicationColor_7b_Hover_Background: @sapIndicationColor_7b_Hover_Background;
  --sapIndicationColor_8: @sapIndicationColor_8;
  --sapIndicationColor_8_Background: @sapIndicationColor_8_Background;
  --sapIndicationColor_8_BorderColor: @sapIndicationColor_8_BorderColor;
  --sapIndicationColor_8_TextColor: @sapIndicationColor_8_TextColor;
  --sapIndicationColor_8_Hover_Background: @sapIndicationColor_8_Hover_Background;
  --sapIndicationColor_8_Active_Background: @sapIndicationColor_8_Active_Background;
  --sapIndicationColor_8_Active_BorderColor: @sapIndicationColor_8_Active_BorderColor;
  --sapIndicationColor_8_Active_TextColor: @sapIndicationColor_8_Active_TextColor;
  --sapIndicationColor_8_Selected_Background: @sapIndicationColor_8_Selected_Background;
  --sapIndicationColor_8_Selected_BorderColor: @sapIndicationColor_8_Selected_BorderColor;
  --sapIndicationColor_8_Selected_TextColor: @sapIndicationColor_8_Selected_TextColor;
  --sapIndicationColor_8b: @sapIndicationColor_8b;
  --sapIndicationColor_8b_TextColor: @sapIndicationColor_8b_TextColor;
  --sapIndicationColor_8b_Background: @sapIndicationColor_8b_Background;
  --sapIndicationColor_8b_BorderColor: @sapIndicationColor_8b_BorderColor;
  --sapIndicationColor_8b_Hover_Background: @sapIndicationColor_8b_Hover_Background;
  --sapIndicationColor_9: @sapIndicationColor_9;
  --sapIndicationColor_9_Background: @sapIndicationColor_9_Background;
  --sapIndicationColor_9_BorderColor: @sapIndicationColor_9_BorderColor;
  --sapIndicationColor_9_TextColor: @sapIndicationColor_9_TextColor;
  --sapIndicationColor_9_Hover_Background: @sapIndicationColor_9_Hover_Background;
  --sapIndicationColor_9_Active_Background: @sapIndicationColor_9_Active_Background;
  --sapIndicationColor_9_Active_BorderColor: @sapIndicationColor_9_Active_BorderColor;
  --sapIndicationColor_9_Active_TextColor: @sapIndicationColor_9_Active_TextColor;
  --sapIndicationColor_9_Selected_Background: @sapIndicationColor_9_Selected_Background;
  --sapIndicationColor_9_Selected_BorderColor: @sapIndicationColor_9_Selected_BorderColor;
  --sapIndicationColor_9_Selected_TextColor: @sapIndicationColor_9_Selected_TextColor;
  --sapIndicationColor_9b: @sapIndicationColor_9b;
  --sapIndicationColor_9b_TextColor: @sapIndicationColor_9b_TextColor;
  --sapIndicationColor_9b_Background: @sapIndicationColor_9b_Background;
  --sapIndicationColor_9b_BorderColor: @sapIndicationColor_9b_BorderColor;
  --sapIndicationColor_9b_Hover_Background: @sapIndicationColor_9b_Hover_Background;
  --sapIndicationColor_10: @sapIndicationColor_10;
  --sapIndicationColor_10_Background: @sapIndicationColor_10_Background;
  --sapIndicationColor_10_BorderColor: @sapIndicationColor_10_BorderColor;
  --sapIndicationColor_10_TextColor: @sapIndicationColor_10_TextColor;
  --sapIndicationColor_10_Hover_Background: @sapIndicationColor_10_Hover_Background;
  --sapIndicationColor_10_Active_Background: @sapIndicationColor_10_Active_Background;
  --sapIndicationColor_10_Active_BorderColor: @sapIndicationColor_10_Active_BorderColor;
  --sapIndicationColor_10_Active_TextColor: @sapIndicationColor_10_Active_TextColor;
  --sapIndicationColor_10_Selected_Background: @sapIndicationColor_10_Selected_Background;
  --sapIndicationColor_10_Selected_BorderColor: @sapIndicationColor_10_Selected_BorderColor;
  --sapIndicationColor_10_Selected_TextColor: @sapIndicationColor_10_Selected_TextColor;
  --sapIndicationColor_10b: @sapIndicationColor_10b;
  --sapIndicationColor_10b_TextColor: @sapIndicationColor_10b_TextColor;
  --sapIndicationColor_10b_Background: @sapIndicationColor_10b_Background;
  --sapIndicationColor_10b_BorderColor: @sapIndicationColor_10b_BorderColor;
  --sapIndicationColor_10b_Hover_Background: @sapIndicationColor_10b_Hover_Background;
  --sapLegend_WorkingBackground: @sapLegend_WorkingBackground;
  --sapLegend_NonWorkingBackground: @sapLegend_NonWorkingBackground;
  --sapLegend_CurrentDateTime: @sapLegend_CurrentDateTime;
  --sapLegendColor1: @sapLegendColor1;
  --sapLegendColor2: @sapLegendColor2;
  --sapLegendColor3: @sapLegendColor3;
  --sapLegendColor4: @sapLegendColor4;
  --sapLegendColor5: @sapLegendColor5;
  --sapLegendColor6: @sapLegendColor6;
  --sapLegendColor7: @sapLegendColor7;
  --sapLegendColor8: @sapLegendColor8;
  --sapLegendColor9: @sapLegendColor9;
  --sapLegendColor10: @sapLegendColor10;
  --sapLegendColor11: @sapLegendColor11;
  --sapLegendColor12: @sapLegendColor12;
  --sapLegendColor13: @sapLegendColor13;
  --sapLegendColor14: @sapLegendColor14;
  --sapLegendColor15: @sapLegendColor15;
  --sapLegendColor16: @sapLegendColor16;
  --sapLegendColor17: @sapLegendColor17;
  --sapLegendColor18: @sapLegendColor18;
  --sapLegendColor19: @sapLegendColor19;
  --sapLegendColor20: @sapLegendColor20;
  --sapLegendBackgroundColor1: @sapLegendBackgroundColor1;
  --sapLegendBackgroundColor2: @sapLegendBackgroundColor2;
  --sapLegendBackgroundColor3: @sapLegendBackgroundColor3;
  --sapLegendBackgroundColor4: @sapLegendBackgroundColor4;
  --sapLegendBackgroundColor5: @sapLegendBackgroundColor5;
  --sapLegendBackgroundColor6: @sapLegendBackgroundColor6;
  --sapLegendBackgroundColor7: @sapLegendBackgroundColor7;
  --sapLegendBackgroundColor8: @sapLegendBackgroundColor8;
  --sapLegendBackgroundColor9: @sapLegendBackgroundColor9;
  --sapLegendBackgroundColor10: @sapLegendBackgroundColor10;
  --sapLegendBackgroundColor11: @sapLegendBackgroundColor11;
  --sapLegendBackgroundColor12: @sapLegendBackgroundColor12;
  --sapLegendBackgroundColor13: @sapLegendBackgroundColor13;
  --sapLegendBackgroundColor14: @sapLegendBackgroundColor14;
  --sapLegendBackgroundColor15: @sapLegendBackgroundColor15;
  --sapLegendBackgroundColor16: @sapLegendBackgroundColor16;
  --sapLegendBackgroundColor17: @sapLegendBackgroundColor17;
  --sapLegendBackgroundColor18: @sapLegendBackgroundColor18;
  --sapLegendBackgroundColor19: @sapLegendBackgroundColor19;
  --sapLegendBackgroundColor20: @sapLegendBackgroundColor20;
  --sapChart_Background: @sapChart_Background;
  --sapChart_ContrastTextShadow: @sapChart_ContrastTextShadow;
  --sapChart_ContrastShadowColor: @sapChart_ContrastShadowColor;
  --sapChart_ContrastLineColor: @sapChart_ContrastLineColor;
  --sapChart_LineColor_1: @sapChart_LineColor_1;
  --sapChart_LineColor_2: @sapChart_LineColor_2;
  --sapChart_LineColor_3: @sapChart_LineColor_3;
  --sapChart_Choropleth_Background: @sapChart_Choropleth_Background;
  --sapChart_ChoroplethRegion_Background: @sapChart_ChoroplethRegion_Background;
  --sapChart_ChoroplethRegion_BorderColor: @sapChart_ChoroplethRegion_BorderColor;
  --sapChart_Data_TextColor: @sapChart_Data_TextColor;
  --sapChart_Data_ContrastTextColor: @sapChart_Data_ContrastTextColor;
  --sapChart_Data_InteractiveColor: @sapChart_Data_InteractiveColor;
  --sapChart_Data_Active_Background: @sapChart_Data_Active_Background;
  --sapChart_OrderedColor_1: @sapChart_OrderedColor_1;
  --sapChart_OrderedColor_2: @sapChart_OrderedColor_2;
  --sapChart_OrderedColor_3: @sapChart_OrderedColor_3;
  --sapChart_OrderedColor_4: @sapChart_OrderedColor_4;
  --sapChart_OrderedColor_5: @sapChart_OrderedColor_5;
  --sapChart_OrderedColor_6: @sapChart_OrderedColor_6;
  --sapChart_OrderedColor_7: @sapChart_OrderedColor_7;
  --sapChart_OrderedColor_8: @sapChart_OrderedColor_8;
  --sapChart_OrderedColor_9: @sapChart_OrderedColor_9;
  --sapChart_OrderedColor_10: @sapChart_OrderedColor_10;
  --sapChart_OrderedColor_11: @sapChart_OrderedColor_11;
  --sapChart_OrderedColor_12: @sapChart_OrderedColor_12;
  --sapChart_Bad: @sapChart_Bad;
  --sapChart_Critical: @sapChart_Critical;
  --sapChart_Good: @sapChart_Good;
  --sapChart_Neutral: @sapChart_Neutral;
  --sapChart_Sequence_1_Plus3: @sapChart_Sequence_1_Plus3;
  --sapChart_Sequence_1_Plus3_TextColor: @sapChart_Sequence_1_Plus3_TextColor;
  --sapChart_Sequence_1_Plus3_TextShadow: @sapChart_Sequence_1_Plus3_TextShadow;
  --sapChart_Sequence_1_Plus2: @sapChart_Sequence_1_Plus2;
  --sapChart_Sequence_1_Plus2_TextColor: @sapChart_Sequence_1_Plus2_TextColor;
  --sapChart_Sequence_1_Plus2_TextShadow: @sapChart_Sequence_1_Plus2_TextShadow;
  --sapChart_Sequence_1_Plus1: @sapChart_Sequence_1_Plus1;
  --sapChart_Sequence_1_Plus1_TextColor: @sapChart_Sequence_1_Plus1_TextColor;
  --sapChart_Sequence_1_Plus1_TextShadow: @sapChart_Sequence_1_Plus1_TextShadow;
  --sapChart_Sequence_1: @sapChart_Sequence_1;
  --sapChart_Sequence_1_TextColor: @sapChart_Sequence_1_TextColor;
  --sapChart_Sequence_1_TextShadow: @sapChart_Sequence_1_TextShadow;
  --sapChart_Sequence_1_BorderColor: @sapChart_Sequence_1_BorderColor;
  --sapChart_Sequence_1_Minus1: @sapChart_Sequence_1_Minus1;
  --sapChart_Sequence_1_Minus1_TextColor: @sapChart_Sequence_1_Minus1_TextColor;
  --sapChart_Sequence_1_Minus1_TextShadow: @sapChart_Sequence_1_Minus1_TextShadow;
  --sapChart_Sequence_1_Minus2: @sapChart_Sequence_1_Minus2;
  --sapChart_Sequence_1_Minus2_TextColor: @sapChart_Sequence_1_Minus2_TextColor;
  --sapChart_Sequence_1_Minus2_TextShadow: @sapChart_Sequence_1_Minus2_TextShadow;
  --sapChart_Sequence_1_Minus3: @sapChart_Sequence_1_Minus3;
  --sapChart_Sequence_1_Minus3_TextColor: @sapChart_Sequence_1_Minus3_TextColor;
  --sapChart_Sequence_1_Minus3_TextShadow: @sapChart_Sequence_1_Minus3_TextShadow;
  --sapChart_Sequence_1_Minus4: @sapChart_Sequence_1_Minus4;
  --sapChart_Sequence_1_Minus4_TextColor: @sapChart_Sequence_1_Minus4_TextColor;
  --sapChart_Sequence_1_Minus4_TextShadow: @sapChart_Sequence_1_Minus4_TextShadow;
  --sapChart_Sequence_1_Minus5: @sapChart_Sequence_1_Minus5;
  --sapChart_Sequence_1_Minus5_TextColor: @sapChart_Sequence_1_Minus5_TextColor;
  --sapChart_Sequence_1_Minus5_TextShadow: @sapChart_Sequence_1_Minus5_TextShadow;
  --sapChart_Sequence_2_Plus3: @sapChart_Sequence_2_Plus3;
  --sapChart_Sequence_2_Plus3_TextColor: @sapChart_Sequence_2_Plus3_TextColor;
  --sapChart_Sequence_2_Plus3_TextShadow: @sapChart_Sequence_2_Plus3_TextShadow;
  --sapChart_Sequence_2_Plus2: @sapChart_Sequence_2_Plus2;
  --sapChart_Sequence_2_Plus2_TextColor: @sapChart_Sequence_2_Plus2_TextColor;
  --sapChart_Sequence_2_Plus2_TextShadow: @sapChart_Sequence_2_Plus2_TextShadow;
  --sapChart_Sequence_2_Plus1: @sapChart_Sequence_2_Plus1;
  --sapChart_Sequence_2_Plus1_TextColor: @sapChart_Sequence_2_Plus1_TextColor;
  --sapChart_Sequence_2_Plus1_TextShadow: @sapChart_Sequence_2_Plus1_TextShadow;
  --sapChart_Sequence_2: @sapChart_Sequence_2;
  --sapChart_Sequence_2_TextColor: @sapChart_Sequence_2_TextColor;
  --sapChart_Sequence_2_TextShadow: @sapChart_Sequence_2_TextShadow;
  --sapChart_Sequence_2_BorderColor: @sapChart_Sequence_2_BorderColor;
  --sapChart_Sequence_2_Minus1: @sapChart_Sequence_2_Minus1;
  --sapChart_Sequence_2_Minus1_TextColor: @sapChart_Sequence_2_Minus1_TextColor;
  --sapChart_Sequence_2_Minus1_TextShadow: @sapChart_Sequence_2_Minus1_TextShadow;
  --sapChart_Sequence_2_Minus2: @sapChart_Sequence_2_Minus2;
  --sapChart_Sequence_2_Minus2_TextColor: @sapChart_Sequence_2_Minus2_TextColor;
  --sapChart_Sequence_2_Minus2_TextShadow: @sapChart_Sequence_2_Minus2_TextShadow;
  --sapChart_Sequence_2_Minus3: @sapChart_Sequence_2_Minus3;
  --sapChart_Sequence_2_Minus3_TextColor: @sapChart_Sequence_2_Minus3_TextColor;
  --sapChart_Sequence_2_Minus3_TextShadow: @sapChart_Sequence_2_Minus3_TextShadow;
  --sapChart_Sequence_2_Minus4: @sapChart_Sequence_2_Minus4;
  --sapChart_Sequence_2_Minus4_TextColor: @sapChart_Sequence_2_Minus4_TextColor;
  --sapChart_Sequence_2_Minus4_TextShadow: @sapChart_Sequence_2_Minus4_TextShadow;
  --sapChart_Sequence_2_Minus5: @sapChart_Sequence_2_Minus5;
  --sapChart_Sequence_2_Minus5_TextColor: @sapChart_Sequence_2_Minus5_TextColor;
  --sapChart_Sequence_2_Minus5_TextShadow: @sapChart_Sequence_2_Minus5_TextShadow;
  --sapChart_Sequence_3_Plus3: @sapChart_Sequence_3_Plus3;
  --sapChart_Sequence_3_Plus3_TextColor: @sapChart_Sequence_3_Plus3_TextColor;
  --sapChart_Sequence_3_Plus3_TextShadow: @sapChart_Sequence_3_Plus3_TextShadow;
  --sapChart_Sequence_3_Plus2: @sapChart_Sequence_3_Plus2;
  --sapChart_Sequence_3_Plus2_TextColor: @sapChart_Sequence_3_Plus2_TextColor;
  --sapChart_Sequence_3_Plus2_TextShadow: @sapChart_Sequence_3_Plus2_TextShadow;
  --sapChart_Sequence_3_Plus1: @sapChart_Sequence_3_Plus1;
  --sapChart_Sequence_3_Plus1_TextColor: @sapChart_Sequence_3_Plus1_TextColor;
  --sapChart_Sequence_3_Plus1_TextShadow: @sapChart_Sequence_3_Plus1_TextShadow;
  --sapChart_Sequence_3: @sapChart_Sequence_3;
  --sapChart_Sequence_3_TextColor: @sapChart_Sequence_3_TextColor;
  --sapChart_Sequence_3_TextShadow: @sapChart_Sequence_3_TextShadow;
  --sapChart_Sequence_3_BorderColor: @sapChart_Sequence_3_BorderColor;
  --sapChart_Sequence_3_Minus1: @sapChart_Sequence_3_Minus1;
  --sapChart_Sequence_3_Minus1_TextColor: @sapChart_Sequence_3_Minus1_TextColor;
  --sapChart_Sequence_3_Minus1_TextShadow: @sapChart_Sequence_3_Minus1_TextShadow;
  --sapChart_Sequence_3_Minus2: @sapChart_Sequence_3_Minus2;
  --sapChart_Sequence_3_Minus2_TextColor: @sapChart_Sequence_3_Minus2_TextColor;
  --sapChart_Sequence_3_Minus2_TextShadow: @sapChart_Sequence_3_Minus2_TextShadow;
  --sapChart_Sequence_3_Minus3: @sapChart_Sequence_3_Minus3;
  --sapChart_Sequence_3_Minus3_TextColor: @sapChart_Sequence_3_Minus3_TextColor;
  --sapChart_Sequence_3_Minus3_TextShadow: @sapChart_Sequence_3_Minus3_TextShadow;
  --sapChart_Sequence_3_Minus4: @sapChart_Sequence_3_Minus4;
  --sapChart_Sequence_3_Minus4_TextColor: @sapChart_Sequence_3_Minus4_TextColor;
  --sapChart_Sequence_3_Minus4_TextShadow: @sapChart_Sequence_3_Minus4_TextShadow;
  --sapChart_Sequence_3_Minus5: @sapChart_Sequence_3_Minus5;
  --sapChart_Sequence_3_Minus5_TextColor: @sapChart_Sequence_3_Minus5_TextColor;
  --sapChart_Sequence_3_Minus5_TextShadow: @sapChart_Sequence_3_Minus5_TextShadow;
  --sapChart_Sequence_4_Plus3: @sapChart_Sequence_4_Plus3;
  --sapChart_Sequence_4_Plus3_TextColor: @sapChart_Sequence_4_Plus3_TextColor;
  --sapChart_Sequence_4_Plus3_TextShadow: @sapChart_Sequence_4_Plus3_TextShadow;
  --sapChart_Sequence_4_Plus2: @sapChart_Sequence_4_Plus2;
  --sapChart_Sequence_4_Plus2_TextColor: @sapChart_Sequence_4_Plus2_TextColor;
  --sapChart_Sequence_4_Plus2_TextShadow: @sapChart_Sequence_4_Plus2_TextShadow;
  --sapChart_Sequence_4_Plus1: @sapChart_Sequence_4_Plus1;
  --sapChart_Sequence_4_Plus1_TextColor: @sapChart_Sequence_4_Plus1_TextColor;
  --sapChart_Sequence_4_Plus1_TextShadow: @sapChart_Sequence_4_Plus1_TextShadow;
  --sapChart_Sequence_4: @sapChart_Sequence_4;
  --sapChart_Sequence_4_TextColor: @sapChart_Sequence_4_TextColor;
  --sapChart_Sequence_4_TextShadow: @sapChart_Sequence_4_TextShadow;
  --sapChart_Sequence_4_BorderColor: @sapChart_Sequence_4_BorderColor;
  --sapChart_Sequence_4_Minus1: @sapChart_Sequence_4_Minus1;
  --sapChart_Sequence_4_Minus1_TextColor: @sapChart_Sequence_4_Minus1_TextColor;
  --sapChart_Sequence_4_Minus1_TextShadow: @sapChart_Sequence_4_Minus1_TextShadow;
  --sapChart_Sequence_4_Minus2: @sapChart_Sequence_4_Minus2;
  --sapChart_Sequence_4_Minus2_TextColor: @sapChart_Sequence_4_Minus2_TextColor;
  --sapChart_Sequence_4_Minus2_TextShadow: @sapChart_Sequence_4_Minus2_TextShadow;
  --sapChart_Sequence_4_Minus3: @sapChart_Sequence_4_Minus3;
  --sapChart_Sequence_4_Minus3_TextColor: @sapChart_Sequence_4_Minus3_TextColor;
  --sapChart_Sequence_4_Minus3_TextShadow: @sapChart_Sequence_4_Minus3_TextShadow;
  --sapChart_Sequence_4_Minus4: @sapChart_Sequence_4_Minus4;
  --sapChart_Sequence_4_Minus4_TextColor: @sapChart_Sequence_4_Minus4_TextColor;
  --sapChart_Sequence_4_Minus4_TextShadow: @sapChart_Sequence_4_Minus4_TextShadow;
  --sapChart_Sequence_4_Minus5: @sapChart_Sequence_4_Minus5;
  --sapChart_Sequence_4_Minus5_TextColor: @sapChart_Sequence_4_Minus5_TextColor;
  --sapChart_Sequence_4_Minus5_TextShadow: @sapChart_Sequence_4_Minus5_TextShadow;
  --sapChart_Sequence_5_Plus3: @sapChart_Sequence_5_Plus3;
  --sapChart_Sequence_5_Plus3_TextColor: @sapChart_Sequence_5_Plus3_TextColor;
  --sapChart_Sequence_5_Plus3_TextShadow: @sapChart_Sequence_5_Plus3_TextShadow;
  --sapChart_Sequence_5_Plus2: @sapChart_Sequence_5_Plus2;
  --sapChart_Sequence_5_Plus2_TextColor: @sapChart_Sequence_5_Plus2_TextColor;
  --sapChart_Sequence_5_Plus2_TextShadow: @sapChart_Sequence_5_Plus2_TextShadow;
  --sapChart_Sequence_5_Plus1: @sapChart_Sequence_5_Plus1;
  --sapChart_Sequence_5_Plus1_TextColor: @sapChart_Sequence_5_Plus1_TextColor;
  --sapChart_Sequence_5_Plus1_TextShadow: @sapChart_Sequence_5_Plus1_TextShadow;
  --sapChart_Sequence_5: @sapChart_Sequence_5;
  --sapChart_Sequence_5_TextColor: @sapChart_Sequence_5_TextColor;
  --sapChart_Sequence_5_TextShadow: @sapChart_Sequence_5_TextShadow;
  --sapChart_Sequence_5_BorderColor: @sapChart_Sequence_5_BorderColor;
  --sapChart_Sequence_5_Minus1: @sapChart_Sequence_5_Minus1;
  --sapChart_Sequence_5_Minus1_TextColor: @sapChart_Sequence_5_Minus1_TextColor;
  --sapChart_Sequence_5_Minus1_TextShadow: @sapChart_Sequence_5_Minus1_TextShadow;
  --sapChart_Sequence_5_Minus2: @sapChart_Sequence_5_Minus2;
  --sapChart_Sequence_5_Minus2_TextColor: @sapChart_Sequence_5_Minus2_TextColor;
  --sapChart_Sequence_5_Minus2_TextShadow: @sapChart_Sequence_5_Minus2_TextShadow;
  --sapChart_Sequence_5_Minus3: @sapChart_Sequence_5_Minus3;
  --sapChart_Sequence_5_Minus3_TextColor: @sapChart_Sequence_5_Minus3_TextColor;
  --sapChart_Sequence_5_Minus3_TextShadow: @sapChart_Sequence_5_Minus3_TextShadow;
  --sapChart_Sequence_5_Minus4: @sapChart_Sequence_5_Minus4;
  --sapChart_Sequence_5_Minus4_TextColor: @sapChart_Sequence_5_Minus4_TextColor;
  --sapChart_Sequence_5_Minus4_TextShadow: @sapChart_Sequence_5_Minus4_TextShadow;
  --sapChart_Sequence_5_Minus5: @sapChart_Sequence_5_Minus5;
  --sapChart_Sequence_5_Minus5_TextColor: @sapChart_Sequence_5_Minus5_TextColor;
  --sapChart_Sequence_5_Minus5_TextShadow: @sapChart_Sequence_5_Minus5_TextShadow;
  --sapChart_Sequence_6_Plus3: @sapChart_Sequence_6_Plus3;
  --sapChart_Sequence_6_Plus3_TextColor: @sapChart_Sequence_6_Plus3_TextColor;
  --sapChart_Sequence_6_Plus3_TextShadow: @sapChart_Sequence_6_Plus3_TextShadow;
  --sapChart_Sequence_6_Plus2: @sapChart_Sequence_6_Plus2;
  --sapChart_Sequence_6_Plus2_TextColor: @sapChart_Sequence_6_Plus2_TextColor;
  --sapChart_Sequence_6_Plus2_TextShadow: @sapChart_Sequence_6_Plus2_TextShadow;
  --sapChart_Sequence_6_Plus1: @sapChart_Sequence_6_Plus1;
  --sapChart_Sequence_6_Plus1_TextColor: @sapChart_Sequence_6_Plus1_TextColor;
  --sapChart_Sequence_6_Plus1_TextShadow: @sapChart_Sequence_6_Plus1_TextShadow;
  --sapChart_Sequence_6: @sapChart_Sequence_6;
  --sapChart_Sequence_6_TextColor: @sapChart_Sequence_6_TextColor;
  --sapChart_Sequence_6_TextShadow: @sapChart_Sequence_6_TextShadow;
  --sapChart_Sequence_6_BorderColor: @sapChart_Sequence_6_BorderColor;
  --sapChart_Sequence_6_Minus1: @sapChart_Sequence_6_Minus1;
  --sapChart_Sequence_6_Minus1_TextColor: @sapChart_Sequence_6_Minus1_TextColor;
  --sapChart_Sequence_6_Minus1_TextShadow: @sapChart_Sequence_6_Minus1_TextShadow;
  --sapChart_Sequence_6_Minus2: @sapChart_Sequence_6_Minus2;
  --sapChart_Sequence_6_Minus2_TextColor: @sapChart_Sequence_6_Minus2_TextColor;
  --sapChart_Sequence_6_Minus2_TextShadow: @sapChart_Sequence_6_Minus2_TextShadow;
  --sapChart_Sequence_6_Minus3: @sapChart_Sequence_6_Minus3;
  --sapChart_Sequence_6_Minus3_TextColor: @sapChart_Sequence_6_Minus3_TextColor;
  --sapChart_Sequence_6_Minus3_TextShadow: @sapChart_Sequence_6_Minus3_TextShadow;
  --sapChart_Sequence_6_Minus4: @sapChart_Sequence_6_Minus4;
  --sapChart_Sequence_6_Minus4_TextColor: @sapChart_Sequence_6_Minus4_TextColor;
  --sapChart_Sequence_6_Minus4_TextShadow: @sapChart_Sequence_6_Minus4_TextShadow;
  --sapChart_Sequence_6_Minus5: @sapChart_Sequence_6_Minus5;
  --sapChart_Sequence_6_Minus5_TextColor: @sapChart_Sequence_6_Minus5_TextColor;
  --sapChart_Sequence_6_Minus5_TextShadow: @sapChart_Sequence_6_Minus5_TextShadow;
  --sapChart_Sequence_7_Plus3: @sapChart_Sequence_7_Plus3;
  --sapChart_Sequence_7_Plus3_TextColor: @sapChart_Sequence_7_Plus3_TextColor;
  --sapChart_Sequence_7_Plus3_TextShadow: @sapChart_Sequence_7_Plus3_TextShadow;
  --sapChart_Sequence_7_Plus2: @sapChart_Sequence_7_Plus2;
  --sapChart_Sequence_7_Plus2_TextColor: @sapChart_Sequence_7_Plus2_TextColor;
  --sapChart_Sequence_7_Plus2_TextShadow: @sapChart_Sequence_7_Plus2_TextShadow;
  --sapChart_Sequence_7_Plus1: @sapChart_Sequence_7_Plus1;
  --sapChart_Sequence_7_Plus1_TextColor: @sapChart_Sequence_7_Plus1_TextColor;
  --sapChart_Sequence_7_Plus1_TextShadow: @sapChart_Sequence_7_Plus1_TextShadow;
  --sapChart_Sequence_7: @sapChart_Sequence_7;
  --sapChart_Sequence_7_TextColor: @sapChart_Sequence_7_TextColor;
  --sapChart_Sequence_7_TextShadow: @sapChart_Sequence_7_TextShadow;
  --sapChart_Sequence_7_BorderColor: @sapChart_Sequence_7_BorderColor;
  --sapChart_Sequence_7_Minus1: @sapChart_Sequence_7_Minus1;
  --sapChart_Sequence_7_Minus1_TextColor: @sapChart_Sequence_7_Minus1_TextColor;
  --sapChart_Sequence_7_Minus1_TextShadow: @sapChart_Sequence_7_Minus1_TextShadow;
  --sapChart_Sequence_7_Minus2: @sapChart_Sequence_7_Minus2;
  --sapChart_Sequence_7_Minus2_TextColor: @sapChart_Sequence_7_Minus2_TextColor;
  --sapChart_Sequence_7_Minus2_TextShadow: @sapChart_Sequence_7_Minus2_TextShadow;
  --sapChart_Sequence_7_Minus3: @sapChart_Sequence_7_Minus3;
  --sapChart_Sequence_7_Minus3_TextColor: @sapChart_Sequence_7_Minus3_TextColor;
  --sapChart_Sequence_7_Minus3_TextShadow: @sapChart_Sequence_7_Minus3_TextShadow;
  --sapChart_Sequence_7_Minus4: @sapChart_Sequence_7_Minus4;
  --sapChart_Sequence_7_Minus4_TextColor: @sapChart_Sequence_7_Minus4_TextColor;
  --sapChart_Sequence_7_Minus4_TextShadow: @sapChart_Sequence_7_Minus4_TextShadow;
  --sapChart_Sequence_7_Minus5: @sapChart_Sequence_7_Minus5;
  --sapChart_Sequence_7_Minus5_TextColor: @sapChart_Sequence_7_Minus5_TextColor;
  --sapChart_Sequence_7_Minus5_TextShadow: @sapChart_Sequence_7_Minus5_TextShadow;
  --sapChart_Sequence_8_Plus3: @sapChart_Sequence_8_Plus3;
  --sapChart_Sequence_8_Plus3_TextColor: @sapChart_Sequence_8_Plus3_TextColor;
  --sapChart_Sequence_8_Plus3_TextShadow: @sapChart_Sequence_8_Plus3_TextShadow;
  --sapChart_Sequence_8_Plus2: @sapChart_Sequence_8_Plus2;
  --sapChart_Sequence_8_Plus2_TextColor: @sapChart_Sequence_8_Plus2_TextColor;
  --sapChart_Sequence_8_Plus2_TextShadow: @sapChart_Sequence_8_Plus2_TextShadow;
  --sapChart_Sequence_8_Plus1: @sapChart_Sequence_8_Plus1;
  --sapChart_Sequence_8_Plus1_TextColor: @sapChart_Sequence_8_Plus1_TextColor;
  --sapChart_Sequence_8_Plus1_TextShadow: @sapChart_Sequence_8_Plus1_TextShadow;
  --sapChart_Sequence_8: @sapChart_Sequence_8;
  --sapChart_Sequence_8_TextColor: @sapChart_Sequence_8_TextColor;
  --sapChart_Sequence_8_TextShadow: @sapChart_Sequence_8_TextShadow;
  --sapChart_Sequence_8_BorderColor: @sapChart_Sequence_8_BorderColor;
  --sapChart_Sequence_8_Minus1: @sapChart_Sequence_8_Minus1;
  --sapChart_Sequence_8_Minus1_TextColor: @sapChart_Sequence_8_Minus1_TextColor;
  --sapChart_Sequence_8_Minus1_TextShadow: @sapChart_Sequence_8_Minus1_TextShadow;
  --sapChart_Sequence_8_Minus2: @sapChart_Sequence_8_Minus2;
  --sapChart_Sequence_8_Minus2_TextColor: @sapChart_Sequence_8_Minus2_TextColor;
  --sapChart_Sequence_8_Minus2_TextShadow: @sapChart_Sequence_8_Minus2_TextShadow;
  --sapChart_Sequence_8_Minus3: @sapChart_Sequence_8_Minus3;
  --sapChart_Sequence_8_Minus3_TextColor: @sapChart_Sequence_8_Minus3_TextColor;
  --sapChart_Sequence_8_Minus3_TextShadow: @sapChart_Sequence_8_Minus3_TextShadow;
  --sapChart_Sequence_8_Minus4: @sapChart_Sequence_8_Minus4;
  --sapChart_Sequence_8_Minus4_TextColor: @sapChart_Sequence_8_Minus4_TextColor;
  --sapChart_Sequence_8_Minus4_TextShadow: @sapChart_Sequence_8_Minus4_TextShadow;
  --sapChart_Sequence_8_Minus5: @sapChart_Sequence_8_Minus5;
  --sapChart_Sequence_8_Minus5_TextColor: @sapChart_Sequence_8_Minus5_TextColor;
  --sapChart_Sequence_8_Minus5_TextShadow: @sapChart_Sequence_8_Minus5_TextShadow;
  --sapChart_Sequence_9_Plus3: @sapChart_Sequence_9_Plus3;
  --sapChart_Sequence_9_Plus3_TextColor: @sapChart_Sequence_9_Plus3_TextColor;
  --sapChart_Sequence_9_Plus3_TextShadow: @sapChart_Sequence_9_Plus3_TextShadow;
  --sapChart_Sequence_9_Plus2: @sapChart_Sequence_9_Plus2;
  --sapChart_Sequence_9_Plus2_TextColor: @sapChart_Sequence_9_Plus2_TextColor;
  --sapChart_Sequence_9_Plus2_TextShadow: @sapChart_Sequence_9_Plus2_TextShadow;
  --sapChart_Sequence_9_Plus1: @sapChart_Sequence_9_Plus1;
  --sapChart_Sequence_9_Plus1_TextColor: @sapChart_Sequence_9_Plus1_TextColor;
  --sapChart_Sequence_9_Plus1_TextShadow: @sapChart_Sequence_9_Plus1_TextShadow;
  --sapChart_Sequence_9: @sapChart_Sequence_9;
  --sapChart_Sequence_9_TextColor: @sapChart_Sequence_9_TextColor;
  --sapChart_Sequence_9_TextShadow: @sapChart_Sequence_9_TextShadow;
  --sapChart_Sequence_9_BorderColor: @sapChart_Sequence_9_BorderColor;
  --sapChart_Sequence_9_Minus1: @sapChart_Sequence_9_Minus1;
  --sapChart_Sequence_9_Minus1_TextColor: @sapChart_Sequence_9_Minus1_TextColor;
  --sapChart_Sequence_9_Minus1_TextShadow: @sapChart_Sequence_9_Minus1_TextShadow;
  --sapChart_Sequence_9_Minus2: @sapChart_Sequence_9_Minus2;
  --sapChart_Sequence_9_Minus2_TextColor: @sapChart_Sequence_9_Minus2_TextColor;
  --sapChart_Sequence_9_Minus2_TextShadow: @sapChart_Sequence_9_Minus2_TextShadow;
  --sapChart_Sequence_9_Minus3: @sapChart_Sequence_9_Minus3;
  --sapChart_Sequence_9_Minus3_TextColor: @sapChart_Sequence_9_Minus3_TextColor;
  --sapChart_Sequence_9_Minus3_TextShadow: @sapChart_Sequence_9_Minus3_TextShadow;
  --sapChart_Sequence_9_Minus4: @sapChart_Sequence_9_Minus4;
  --sapChart_Sequence_9_Minus4_TextColor: @sapChart_Sequence_9_Minus4_TextColor;
  --sapChart_Sequence_9_Minus4_TextShadow: @sapChart_Sequence_9_Minus4_TextShadow;
  --sapChart_Sequence_9_Minus5: @sapChart_Sequence_9_Minus5;
  --sapChart_Sequence_9_Minus5_TextColor: @sapChart_Sequence_9_Minus5_TextColor;
  --sapChart_Sequence_9_Minus5_TextShadow: @sapChart_Sequence_9_Minus5_TextShadow;
  --sapChart_Sequence_10_Plus3: @sapChart_Sequence_10_Plus3;
  --sapChart_Sequence_10_Plus3_TextColor: @sapChart_Sequence_10_Plus3_TextColor;
  --sapChart_Sequence_10_Plus3_TextShadow: @sapChart_Sequence_10_Plus3_TextShadow;
  --sapChart_Sequence_10_Plus2: @sapChart_Sequence_10_Plus2;
  --sapChart_Sequence_10_Plus2_TextColor: @sapChart_Sequence_10_Plus2_TextColor;
  --sapChart_Sequence_10_Plus2_TextShadow: @sapChart_Sequence_10_Plus2_TextShadow;
  --sapChart_Sequence_10_Plus1: @sapChart_Sequence_10_Plus1;
  --sapChart_Sequence_10_Plus1_TextColor: @sapChart_Sequence_10_Plus1_TextColor;
  --sapChart_Sequence_10_Plus1_TextShadow: @sapChart_Sequence_10_Plus1_TextShadow;
  --sapChart_Sequence_10: @sapChart_Sequence_10;
  --sapChart_Sequence_10_TextColor: @sapChart_Sequence_10_TextColor;
  --sapChart_Sequence_10_TextShadow: @sapChart_Sequence_10_TextShadow;
  --sapChart_Sequence_10_BorderColor: @sapChart_Sequence_10_BorderColor;
  --sapChart_Sequence_10_Minus1: @sapChart_Sequence_10_Minus1;
  --sapChart_Sequence_10_Minus1_TextColor: @sapChart_Sequence_10_Minus1_TextColor;
  --sapChart_Sequence_10_Minus1_TextShadow: @sapChart_Sequence_10_Minus1_TextShadow;
  --sapChart_Sequence_10_Minus2: @sapChart_Sequence_10_Minus2;
  --sapChart_Sequence_10_Minus2_TextColor: @sapChart_Sequence_10_Minus2_TextColor;
  --sapChart_Sequence_10_Minus2_TextShadow: @sapChart_Sequence_10_Minus2_TextShadow;
  --sapChart_Sequence_10_Minus3: @sapChart_Sequence_10_Minus3;
  --sapChart_Sequence_10_Minus3_TextColor: @sapChart_Sequence_10_Minus3_TextColor;
  --sapChart_Sequence_10_Minus3_TextShadow: @sapChart_Sequence_10_Minus3_TextShadow;
  --sapChart_Sequence_10_Minus4: @sapChart_Sequence_10_Minus4;
  --sapChart_Sequence_10_Minus4_TextColor: @sapChart_Sequence_10_Minus4_TextColor;
  --sapChart_Sequence_10_Minus4_TextShadow: @sapChart_Sequence_10_Minus4_TextShadow;
  --sapChart_Sequence_10_Minus5: @sapChart_Sequence_10_Minus5;
  --sapChart_Sequence_10_Minus5_TextColor: @sapChart_Sequence_10_Minus5_TextColor;
  --sapChart_Sequence_10_Minus5_TextShadow: @sapChart_Sequence_10_Minus5_TextShadow;
  --sapChart_Sequence_11_Plus3: @sapChart_Sequence_11_Plus3;
  --sapChart_Sequence_11_Plus3_TextColor: @sapChart_Sequence_11_Plus3_TextColor;
  --sapChart_Sequence_11_Plus3_TextShadow: @sapChart_Sequence_11_Plus3_TextShadow;
  --sapChart_Sequence_11_Plus2: @sapChart_Sequence_11_Plus2;
  --sapChart_Sequence_11_Plus2_TextColor: @sapChart_Sequence_11_Plus2_TextColor;
  --sapChart_Sequence_11_Plus2_TextShadow: @sapChart_Sequence_11_Plus2_TextShadow;
  --sapChart_Sequence_11_Plus1: @sapChart_Sequence_11_Plus1;
  --sapChart_Sequence_11_Plus1_TextColor: @sapChart_Sequence_11_Plus1_TextColor;
  --sapChart_Sequence_11_Plus1_TextShadow: @sapChart_Sequence_11_Plus1_TextShadow;
  --sapChart_Sequence_11: @sapChart_Sequence_11;
  --sapChart_Sequence_11_TextColor: @sapChart_Sequence_11_TextColor;
  --sapChart_Sequence_11_TextShadow: @sapChart_Sequence_11_TextShadow;
  --sapChart_Sequence_11_BorderColor: @sapChart_Sequence_11_BorderColor;
  --sapChart_Sequence_11_Minus1: @sapChart_Sequence_11_Minus1;
  --sapChart_Sequence_11_Minus1_TextColor: @sapChart_Sequence_11_Minus1_TextColor;
  --sapChart_Sequence_11_Minus1_TextShadow: @sapChart_Sequence_11_Minus1_TextShadow;
  --sapChart_Sequence_11_Minus2: @sapChart_Sequence_11_Minus2;
  --sapChart_Sequence_11_Minus2_TextColor: @sapChart_Sequence_11_Minus2_TextColor;
  --sapChart_Sequence_11_Minus2_TextShadow: @sapChart_Sequence_11_Minus2_TextShadow;
  --sapChart_Sequence_11_Minus3: @sapChart_Sequence_11_Minus3;
  --sapChart_Sequence_11_Minus3_TextColor: @sapChart_Sequence_11_Minus3_TextColor;
  --sapChart_Sequence_11_Minus3_TextShadow: @sapChart_Sequence_11_Minus3_TextShadow;
  --sapChart_Sequence_11_Minus4: @sapChart_Sequence_11_Minus4;
  --sapChart_Sequence_11_Minus4_TextColor: @sapChart_Sequence_11_Minus4_TextColor;
  --sapChart_Sequence_11_Minus4_TextShadow: @sapChart_Sequence_11_Minus4_TextShadow;
  --sapChart_Sequence_11_Minus5: @sapChart_Sequence_11_Minus5;
  --sapChart_Sequence_11_Minus5_TextColor: @sapChart_Sequence_11_Minus5_TextColor;
  --sapChart_Sequence_11_Minus5_TextShadow: @sapChart_Sequence_11_Minus5_TextShadow;
  --sapChart_Sequence_12_Plus3: @sapChart_Sequence_12_Plus3;
  --sapChart_Sequence_12_Plus3_TextColor: @sapChart_Sequence_12_Plus3_TextColor;
  --sapChart_Sequence_12_Plus3_TextShadow: @sapChart_Sequence_12_Plus3_TextShadow;
  --sapChart_Sequence_12_Plus2: @sapChart_Sequence_12_Plus2;
  --sapChart_Sequence_12_Plus2_TextColor: @sapChart_Sequence_12_Plus2_TextColor;
  --sapChart_Sequence_12_Plus2_TextShadow: @sapChart_Sequence_12_Plus2_TextShadow;
  --sapChart_Sequence_12_Plus1: @sapChart_Sequence_12_Plus1;
  --sapChart_Sequence_12_Plus1_TextColor: @sapChart_Sequence_12_Plus1_TextColor;
  --sapChart_Sequence_12_Plus1_TextShadow: @sapChart_Sequence_12_Plus1_TextShadow;
  --sapChart_Sequence_12: @sapChart_Sequence_12;
  --sapChart_Sequence_12_TextColor: @sapChart_Sequence_12_TextColor;
  --sapChart_Sequence_12_TextShadow: @sapChart_Sequence_12_TextShadow;
  --sapChart_Sequence_12_BorderColor: @sapChart_Sequence_12_BorderColor;
  --sapChart_Sequence_12_Minus1: @sapChart_Sequence_12_Minus1;
  --sapChart_Sequence_12_Minus1_TextColor: @sapChart_Sequence_12_Minus1_TextColor;
  --sapChart_Sequence_12_Minus1_TextShadow: @sapChart_Sequence_12_Minus1_TextShadow;
  --sapChart_Sequence_12_Minus2: @sapChart_Sequence_12_Minus2;
  --sapChart_Sequence_12_Minus2_TextColor: @sapChart_Sequence_12_Minus2_TextColor;
  --sapChart_Sequence_12_Minus2_TextShadow: @sapChart_Sequence_12_Minus2_TextShadow;
  --sapChart_Sequence_12_Minus3: @sapChart_Sequence_12_Minus3;
  --sapChart_Sequence_12_Minus3_TextColor: @sapChart_Sequence_12_Minus3_TextColor;
  --sapChart_Sequence_12_Minus3_TextShadow: @sapChart_Sequence_12_Minus3_TextShadow;
  --sapChart_Sequence_12_Minus4: @sapChart_Sequence_12_Minus4;
  --sapChart_Sequence_12_Minus4_TextColor: @sapChart_Sequence_12_Minus4_TextColor;
  --sapChart_Sequence_12_Minus4_TextShadow: @sapChart_Sequence_12_Minus4_TextShadow;
  --sapChart_Sequence_12_Minus5: @sapChart_Sequence_12_Minus5;
  --sapChart_Sequence_12_Minus5_TextColor: @sapChart_Sequence_12_Minus5_TextColor;
  --sapChart_Sequence_12_Minus5_TextShadow: @sapChart_Sequence_12_Minus5_TextShadow;
  --sapChart_Sequence_Bad_Plus3: @sapChart_Sequence_Bad_Plus3;
  --sapChart_Sequence_Bad_Plus3_TextColor: @sapChart_Sequence_Bad_Plus3_TextColor;
  --sapChart_Sequence_Bad_Plus3_TextShadow: @sapChart_Sequence_Bad_Plus3_TextShadow;
  --sapChart_Sequence_Bad_Plus2: @sapChart_Sequence_Bad_Plus2;
  --sapChart_Sequence_Bad_Plus2_TextColor: @sapChart_Sequence_Bad_Plus2_TextColor;
  --sapChart_Sequence_Bad_Plus2_TextShadow: @sapChart_Sequence_Bad_Plus2_TextShadow;
  --sapChart_Sequence_Bad_Plus1: @sapChart_Sequence_Bad_Plus1;
  --sapChart_Sequence_Bad_Plus1_TextColor: @sapChart_Sequence_Bad_Plus1_TextColor;
  --sapChart_Sequence_Bad_Plus1_TextShadow: @sapChart_Sequence_Bad_Plus1_TextShadow;
  --sapChart_Sequence_Bad: @sapChart_Sequence_Bad;
  --sapChart_Sequence_Bad_TextColor: @sapChart_Sequence_Bad_TextColor;
  --sapChart_Sequence_Bad_TextShadow: @sapChart_Sequence_Bad_TextShadow;
  --sapChart_Sequence_Bad_BorderColor: @sapChart_Sequence_Bad_BorderColor;
  --sapChart_Sequence_Bad_Minus1: @sapChart_Sequence_Bad_Minus1;
  --sapChart_Sequence_Bad_Minus1_TextColor: @sapChart_Sequence_Bad_Minus1_TextColor;
  --sapChart_Sequence_Bad_Minus1_TextShadow: @sapChart_Sequence_Bad_Minus1_TextShadow;
  --sapChart_Sequence_Bad_Minus2: @sapChart_Sequence_Bad_Minus2;
  --sapChart_Sequence_Bad_Minus2_TextColor: @sapChart_Sequence_Bad_Minus2_TextColor;
  --sapChart_Sequence_Bad_Minus2_TextShadow: @sapChart_Sequence_Bad_Minus2_TextShadow;
  --sapChart_Sequence_Bad_Minus3: @sapChart_Sequence_Bad_Minus3;
  --sapChart_Sequence_Bad_Minus3_TextColor: @sapChart_Sequence_Bad_Minus3_TextColor;
  --sapChart_Sequence_Bad_Minus3_TextShadow: @sapChart_Sequence_Bad_Minus3_TextShadow;
  --sapChart_Sequence_Bad_Minus4: @sapChart_Sequence_Bad_Minus4;
  --sapChart_Sequence_Bad_Minus4_TextColor: @sapChart_Sequence_Bad_Minus4_TextColor;
  --sapChart_Sequence_Bad_Minus4_TextShadow: @sapChart_Sequence_Bad_Minus4_TextShadow;
  --sapChart_Sequence_Bad_Minus5: @sapChart_Sequence_Bad_Minus5;
  --sapChart_Sequence_Bad_Minus5_TextColor: @sapChart_Sequence_Bad_Minus5_TextColor;
  --sapChart_Sequence_Bad_Minus5_TextShadow: @sapChart_Sequence_Bad_Minus5_TextShadow;
  --sapChart_Sequence_Critical_Plus3: @sapChart_Sequence_Critical_Plus3;
  --sapChart_Sequence_Critical_Plus3_TextColor: @sapChart_Sequence_Critical_Plus3_TextColor;
  --sapChart_Sequence_Critical_Plus3_TextShadow: @sapChart_Sequence_Critical_Plus3_TextShadow;
  --sapChart_Sequence_Critical_Plus2: @sapChart_Sequence_Critical_Plus2;
  --sapChart_Sequence_Critical_Plus2_TextColor: @sapChart_Sequence_Critical_Plus2_TextColor;
  --sapChart_Sequence_Critical_Plus2_TextShadow: @sapChart_Sequence_Critical_Plus2_TextShadow;
  --sapChart_Sequence_Critical_Plus1: @sapChart_Sequence_Critical_Plus1;
  --sapChart_Sequence_Critical_Plus1_TextColor: @sapChart_Sequence_Critical_Plus1_TextColor;
  --sapChart_Sequence_Critical_Plus1_TextShadow: @sapChart_Sequence_Critical_Plus1_TextShadow;
  --sapChart_Sequence_Critical: @sapChart_Sequence_Critical;
  --sapChart_Sequence_Critical_TextColor: @sapChart_Sequence_Critical_TextColor;
  --sapChart_Sequence_Critical_TextShadow: @sapChart_Sequence_Critical_TextShadow;
  --sapChart_Sequence_Critical_BorderColor: @sapChart_Sequence_Critical_BorderColor;
  --sapChart_Sequence_Critical_Minus1: @sapChart_Sequence_Critical_Minus1;
  --sapChart_Sequence_Critical_Minus1_TextColor: @sapChart_Sequence_Critical_Minus1_TextColor;
  --sapChart_Sequence_Critical_Minus1_TextShadow: @sapChart_Sequence_Critical_Minus1_TextShadow;
  --sapChart_Sequence_Critical_Minus2: @sapChart_Sequence_Critical_Minus2;
  --sapChart_Sequence_Critical_Minus2_TextColor: @sapChart_Sequence_Critical_Minus2_TextColor;
  --sapChart_Sequence_Critical_Minus2_TextShadow: @sapChart_Sequence_Critical_Minus2_TextShadow;
  --sapChart_Sequence_Critical_Minus3: @sapChart_Sequence_Critical_Minus3;
  --sapChart_Sequence_Critical_Minus3_TextColor: @sapChart_Sequence_Critical_Minus3_TextColor;
  --sapChart_Sequence_Critical_Minus3_TextShadow: @sapChart_Sequence_Critical_Minus3_TextShadow;
  --sapChart_Sequence_Critical_Minus4: @sapChart_Sequence_Critical_Minus4;
  --sapChart_Sequence_Critical_Minus4_TextColor: @sapChart_Sequence_Critical_Minus4_TextColor;
  --sapChart_Sequence_Critical_Minus4_TextShadow: @sapChart_Sequence_Critical_Minus4_TextShadow;
  --sapChart_Sequence_Critical_Minus5: @sapChart_Sequence_Critical_Minus5;
  --sapChart_Sequence_Critical_Minus5_TextColor: @sapChart_Sequence_Critical_Minus5_TextColor;
  --sapChart_Sequence_Critical_Minus5_TextShadow: @sapChart_Sequence_Critical_Minus5_TextShadow;
  --sapChart_Sequence_Good_Plus3: @sapChart_Sequence_Good_Plus3;
  --sapChart_Sequence_Good_Plus3_TextColor: @sapChart_Sequence_Good_Plus3_TextColor;
  --sapChart_Sequence_Good_Plus3_TextShadow: @sapChart_Sequence_Good_Plus3_TextShadow;
  --sapChart_Sequence_Good_Plus2: @sapChart_Sequence_Good_Plus2;
  --sapChart_Sequence_Good_Plus2_TextColor: @sapChart_Sequence_Good_Plus2_TextColor;
  --sapChart_Sequence_Good_Plus2_TextShadow: @sapChart_Sequence_Good_Plus2_TextShadow;
  --sapChart_Sequence_Good_Plus1: @sapChart_Sequence_Good_Plus1;
  --sapChart_Sequence_Good_Plus1_TextColor: @sapChart_Sequence_Good_Plus1_TextColor;
  --sapChart_Sequence_Good_Plus1_TextShadow: @sapChart_Sequence_Good_Plus1_TextShadow;
  --sapChart_Sequence_Good: @sapChart_Sequence_Good;
  --sapChart_Sequence_Good_TextColor: @sapChart_Sequence_Good_TextColor;
  --sapChart_Sequence_Good_TextShadow: @sapChart_Sequence_Good_TextShadow;
  --sapChart_Sequence_Good_BorderColor: @sapChart_Sequence_Good_BorderColor;
  --sapChart_Sequence_Good_Minus1: @sapChart_Sequence_Good_Minus1;
  --sapChart_Sequence_Good_Minus1_TextColor: @sapChart_Sequence_Good_Minus1_TextColor;
  --sapChart_Sequence_Good_Minus1_TextShadow: @sapChart_Sequence_Good_Minus1_TextShadow;
  --sapChart_Sequence_Good_Minus2: @sapChart_Sequence_Good_Minus2;
  --sapChart_Sequence_Good_Minus2_TextColor: @sapChart_Sequence_Good_Minus2_TextColor;
  --sapChart_Sequence_Good_Minus2_TextShadow: @sapChart_Sequence_Good_Minus2_TextShadow;
  --sapChart_Sequence_Good_Minus3: @sapChart_Sequence_Good_Minus3;
  --sapChart_Sequence_Good_Minus3_TextColor: @sapChart_Sequence_Good_Minus3_TextColor;
  --sapChart_Sequence_Good_Minus3_TextShadow: @sapChart_Sequence_Good_Minus3_TextShadow;
  --sapChart_Sequence_Good_Minus4: @sapChart_Sequence_Good_Minus4;
  --sapChart_Sequence_Good_Minus4_TextColor: @sapChart_Sequence_Good_Minus4_TextColor;
  --sapChart_Sequence_Good_Minus4_TextShadow: @sapChart_Sequence_Good_Minus4_TextShadow;
  --sapChart_Sequence_Good_Minus5: @sapChart_Sequence_Good_Minus5;
  --sapChart_Sequence_Good_Minus5_TextColor: @sapChart_Sequence_Good_Minus5_TextColor;
  --sapChart_Sequence_Good_Minus5_TextShadow: @sapChart_Sequence_Good_Minus5_TextShadow;
  --sapChart_Sequence_Neutral_Plus3: @sapChart_Sequence_Neutral_Plus3;
  --sapChart_Sequence_Neutral_Plus3_TextColor: @sapChart_Sequence_Neutral_Plus3_TextColor;
  --sapChart_Sequence_Neutral_Plus3_TextShadow: @sapChart_Sequence_Neutral_Plus3_TextShadow;
  --sapChart_Sequence_Neutral_Plus2: @sapChart_Sequence_Neutral_Plus2;
  --sapChart_Sequence_Neutral_Plus2_TextColor: @sapChart_Sequence_Neutral_Plus2_TextColor;
  --sapChart_Sequence_Neutral_Plus2_TextShadow: @sapChart_Sequence_Neutral_Plus2_TextShadow;
  --sapChart_Sequence_Neutral_Plus1: @sapChart_Sequence_Neutral_Plus1;
  --sapChart_Sequence_Neutral_Plus1_TextColor: @sapChart_Sequence_Neutral_Plus1_TextColor;
  --sapChart_Sequence_Neutral_Plus1_TextShadow: @sapChart_Sequence_Neutral_Plus1_TextShadow;
  --sapChart_Sequence_Neutral: @sapChart_Sequence_Neutral;
  --sapChart_Sequence_Neutral_TextColor: @sapChart_Sequence_Neutral_TextColor;
  --sapChart_Sequence_Neutral_TextShadow: @sapChart_Sequence_Neutral_TextShadow;
  --sapChart_Sequence_Neutral_BorderColor: @sapChart_Sequence_Neutral_BorderColor;
  --sapChart_Sequence_Neutral_Minus1: @sapChart_Sequence_Neutral_Minus1;
  --sapChart_Sequence_Neutral_Minus1_TextColor: @sapChart_Sequence_Neutral_Minus1_TextColor;
  --sapChart_Sequence_Neutral_Minus1_TextShadow: @sapChart_Sequence_Neutral_Minus1_TextShadow;
  --sapChart_Sequence_Neutral_Minus2: @sapChart_Sequence_Neutral_Minus2;
  --sapChart_Sequence_Neutral_Minus2_TextColor: @sapChart_Sequence_Neutral_Minus2_TextColor;
  --sapChart_Sequence_Neutral_Minus2_TextShadow: @sapChart_Sequence_Neutral_Minus2_TextShadow;
  --sapChart_Sequence_Neutral_Minus3: @sapChart_Sequence_Neutral_Minus3;
  --sapChart_Sequence_Neutral_Minus3_TextColor: @sapChart_Sequence_Neutral_Minus3_TextColor;
  --sapChart_Sequence_Neutral_Minus3_TextShadow: @sapChart_Sequence_Neutral_Minus3_TextShadow;
  --sapChart_Sequence_Neutral_Minus4: @sapChart_Sequence_Neutral_Minus4;
  --sapChart_Sequence_Neutral_Minus4_TextColor: @sapChart_Sequence_Neutral_Minus4_TextColor;
  --sapChart_Sequence_Neutral_Minus4_TextShadow: @sapChart_Sequence_Neutral_Minus4_TextShadow;
  --sapChart_Sequence_Neutral_Minus5: @sapChart_Sequence_Neutral_Minus5;
  --sapChart_Sequence_Neutral_Minus5_TextColor: @sapChart_Sequence_Neutral_Minus5_TextColor;
  --sapChart_Sequence_Neutral_Minus5_TextShadow: @sapChart_Sequence_Neutral_Minus5_TextShadow;
  --sapFontUrl_SAP-icons_ttf: @sapFontUrl_SAP-icons_ttf;
  --sapFontUrl_SAP-icons_woff: @sapFontUrl_SAP-icons_woff;
  --sapFontUrl_SAP-icons_woff2: @sapFontUrl_SAP-icons_woff2;
  --sapFontUrl_SAP-icons-TNT_ttf: @sapFontUrl_SAP-icons-TNT_ttf;
  --sapFontUrl_SAP-icons-TNT_woff: @sapFontUrl_SAP-icons-TNT_woff;
  --sapFontUrl_SAP-icons-TNT_woff2: @sapFontUrl_SAP-icons-TNT_woff2;
  --sapFontUrl_SAP-icons-Business-Suite_ttf: @sapFontUrl_SAP-icons-Business-Suite_ttf;
  --sapFontUrl_SAP-icons-Business-Suite_woff: @sapFontUrl_SAP-icons-Business-Suite_woff;
  --sapFontUrl_SAP-icons-Business-Suite_woff2: @sapFontUrl_SAP-icons-Business-Suite_woff2;
  --sapFontUrl_72_Regular_woff2: @sapFontUrl_72_Regular_woff2;
  --sapFontUrl_72_Regular_woff: @sapFontUrl_72_Regular_woff;
  --sapFontUrl_72_Regular_full_woff2: @sapFontUrl_72_Regular_full_woff2;
  --sapFontUrl_72_Regular_full_woff: @sapFontUrl_72_Regular_full_woff;
  --sapFontUrl_72_Bold_woff2: @sapFontUrl_72_Bold_woff2;
  --sapFontUrl_72_Bold_woff: @sapFontUrl_72_Bold_woff;
  --sapFontUrl_72_Bold_full_woff2: @sapFontUrl_72_Bold_full_woff2;
  --sapFontUrl_72_Bold_full_woff: @sapFontUrl_72_Bold_full_woff;
  --sapFontUrl_72_Semibold_woff2: @sapFontUrl_72_Semibold_woff2;
  --sapFontUrl_72_Semibold_woff: @sapFontUrl_72_Semibold_woff;
  --sapFontUrl_72_Semibold_full_woff2: @sapFontUrl_72_Semibold_full_woff2;
  --sapFontUrl_72_Semibold_full_woff: @sapFontUrl_72_Semibold_full_woff;
  --sapFontUrl_72_SemiboldDuplex_woff2: @sapFontUrl_72_SemiboldDuplex_woff2;
  --sapFontUrl_72_SemiboldDuplex_woff: @sapFontUrl_72_SemiboldDuplex_woff;
  --sapFontUrl_72_SemiboldDuplex_full_woff2: @sapFontUrl_72_SemiboldDuplex_full_woff2;
  --sapFontUrl_72_SemiboldDuplex_full_woff: @sapFontUrl_72_SemiboldDuplex_full_woff;
  --sapFontUrl_72_Light_woff2: @sapFontUrl_72_Light_woff2;
  --sapFontUrl_72_Light_woff: @sapFontUrl_72_Light_woff;
  --sapFontUrl_72_Light_full_woff2: @sapFontUrl_72_Light_full_woff2;
  --sapFontUrl_72_Light_full_woff: @sapFontUrl_72_Light_full_woff;
  --sapFontUrl_72_Black_woff2: @sapFontUrl_72_Black_woff2;
  --sapFontUrl_72_Black_woff: @sapFontUrl_72_Black_woff;
  --sapFontUrl_72_Black_full_woff2: @sapFontUrl_72_Black_full_woff2;
  --sapFontUrl_72_Black_full_woff: @sapFontUrl_72_Black_full_woff;
  --sapFontUrl_72_BoldItalic_woff2: @sapFontUrl_72_BoldItalic_woff2;
  --sapFontUrl_72_BoldItalic_woff: @sapFontUrl_72_BoldItalic_woff;
  --sapFontUrl_72_BoldItalic_full_woff2: @sapFontUrl_72_BoldItalic_full_woff2;
  --sapFontUrl_72_BoldItalic_full_woff: @sapFontUrl_72_BoldItalic_full_woff;
  --sapFontUrl_72_Condensed_woff2: @sapFontUrl_72_Condensed_woff2;
  --sapFontUrl_72_Condensed_woff: @sapFontUrl_72_Condensed_woff;
  --sapFontUrl_72_Condensed_full_woff2: @sapFontUrl_72_Condensed_full_woff2;
  --sapFontUrl_72_Condensed_full_woff: @sapFontUrl_72_Condensed_full_woff;
  --sapFontUrl_72_CondensedBold_woff2: @sapFontUrl_72_CondensedBold_woff2;
  --sapFontUrl_72_CondensedBold_woff: @sapFontUrl_72_CondensedBold_woff;
  --sapFontUrl_72_CondensedBold_full_woff2: @sapFontUrl_72_CondensedBold_full_woff2;
  --sapFontUrl_72_CondensedBold_full_woff: @sapFontUrl_72_CondensedBold_full_woff;
  --sapFontUrl_72_Italic_woff2: @sapFontUrl_72_Italic_woff2;
  --sapFontUrl_72_Italic_woff: @sapFontUrl_72_Italic_woff;
  --sapFontUrl_72_Italic_full_woff2: @sapFontUrl_72_Italic_full_woff2;
  --sapFontUrl_72_Italic_full_woff: @sapFontUrl_72_Italic_full_woff;
  --sapFontUrl_72Mono_Regular_woff2: @sapFontUrl_72Mono_Regular_woff2;
  --sapFontUrl_72Mono_Regular_woff: @sapFontUrl_72Mono_Regular_woff;
  --sapFontUrl_72Mono_Regular_full_woff2: @sapFontUrl_72Mono_Regular_full_woff2;
  --sapFontUrl_72Mono_Regular_full_woff: @sapFontUrl_72Mono_Regular_full_woff;
  --sapFontUrl_72Mono_Bold_woff2: @sapFontUrl_72Mono_Bold_woff2;
  --sapFontUrl_72Mono_Bold_woff: @sapFontUrl_72Mono_Bold_woff;
  --sapFontUrl_72Mono_Bold_full_woff2: @sapFontUrl_72Mono_Bold_full_woff2;
  --sapFontUrl_72Mono_Bold_full_woff: @sapFontUrl_72Mono_Bold_full_woff;
  --sapSapThemeId: @sapSapThemeId;
  --sapBreakpoint_S_Min: @sapBreakpoint_S_Min;
  --sapBreakpoint_M_Min: @sapBreakpoint_M_Min;
  --sapBreakpoint_L_Min: @sapBreakpoint_L_Min;
  --sapBreakpoint_XL_Min: @sapBreakpoint_XL_Min;
}
/*<SAP_FREETEXT_LESS>*/
.sapCss_BackgroundImage_sapCompanyLogo() {
.background-image--sapCompanyLogo {
background-image: var(--sapCompanyLogo);
}
}
.sapCss_BackgroundImage_sapCompanyLogo();
.sapCss_BackgroundImage_sapBackgroundImage() {
.background-image--sapBackgroundImage {
background-image: var(--sapBackgroundImage);
}
}
.sapCss_BackgroundImage_sapBackgroundImage();
.sapCss_BackgroundImage_sapShell_BackgroundImage() {
.background-image--sapShell_BackgroundImage {
background-image: var(--sapShell_BackgroundImage);
}
}
.sapCss_BackgroundImage_sapShell_BackgroundImage();
/*</SAP_FREETEXT_LESS>*//*!SAP_POSTPROCESS_REDUCE_END*/

/* END "skeleton.less" */


@import "../../../../../../Base/baseLib/baseTheme/base.less"; /* ORIGINAL IMPORT PATH: "base.less" */

@import "global.less";
/* START "shared.less" */
/* ====================== */
/* Shared CSS Base theme  */
/* ====================== */

.sapUiThemeDesignerCustomCssCheck() when(@sapUiThemeDesignerCustomCss = true){
	content: 'true';
}
.sapUiThemeDesignerCustomCssCheck() when not(@sapUiThemeDesignerCustomCss = true){
}

link[id^="sap-ui-theme-"]::after,
.sapUiThemeDesignerCustomCss {
	.sapUiThemeDesignerCustomCssCheck;
}

.sapUiBody {
	background-color: @sapUiExtraLightBG;
	color: @sapUiText;
	font-family: @sapUiFontFamily;
	font-size: @sapUiFontSize;
	-webkit-tap-highlight-color: rgba(0,0,0,0); /* to prevent touch highlight on the entire body */
	forced-color-adjust: @sapUiContentForcedColorAdjust;
}

.sapUiArea {
	background-color: @sapUiExtraLightBG;
	color: @sapUiText;
	font-family: @sapUiFontFamily;
	font-size: @sapUiFontSize;
}

/*
 * used for static (Core) and hidden (HTML) area
 * (TODO: think about renaming static area also to hidden since static is not
 *        required for newer browsers anymore => position: static)
 */
.sapUiHidden {
	position: absolute;
	visibility: hidden;
	left: -10000px;
	top: -10000px;
	background-color: @sapUiExtraLightBG; /* repeat the body style in case the application adapts it */
	color: @sapUiText;
	font-family: @sapUiFontFamily;
	font-size: @sapUiFontSize;
}

.sapUiForcedHidden, .sapUiForcedHidden * {
	visibility: hidden !important;
}

.sapUiCorePlaintext {
	font-family: @sapUiFontFamily;
	font-size: @sapUiFontSize;
	line-height: @sapUiLineHeight;
}

.sapUiCoreDefaultFont {
	font-family: @sapUiFontFamily;
	font-size: @sapUiFontSize;
}

.sapUiCoreDefaultCursor {
	cursor: default;
}

.sapUiBLy {
	background-color: #CCCCCC;
	opacity: 0.6;
	filter: alpha(opacity=60);
	top: 0px;
	left: 0px;
	right: 0px;
	bottom: 0px;
	position: fixed;
	outline: 0 none;
}

.sapUiBLyWithin {
	left: auto;
	right: auto;
	top: auto;
	bottom: auto;
}
.sapUiBLyBack{
	/* to prevent HTML page from scrolling if blocked */
	overflow: hidden;
}

.sapUiPopupShield {
	position: absolute;
}

.sapUiPopupInitial {
	opacity: 0;
}

[data-sap-ui-type] {
	visibility: hidden;
}

/* CSS for windows 8 combi devices */
.sapUiBody {
	/* disable pinch zooming */
	content-zooming: none;
}

@media (max-width:599px) {
	.sapUiHideOnPhone {
		display : none !important;
	}
	.sapUiVisibleOnlyOnTablet {
		display : none !important;
	}
	.sapUiVisibleOnlyOnDesktop {
		display : none !important;
	}
}

@media (min-width:600px) and (max-width:1023px) {
	.sapUiHideOnTablet {
		display : none !important;
	}
	.sapUiVisibleOnlyOnDesktop {
		display : none !important;
	}
	.sapUiVisibleOnlyOnPhone {
		display : none !important;
	}
}

@media (min-width:1024px) {
	.sapUiHideOnDesktop {
		display : none !important;
	}
	.sapUiVisibleOnlyOnTablet {
		display : none !important;
	}
	.sapUiVisibleOnlyOnPhone {
		display : none !important;
	}
}

.sapUiOverlay {
	background-color: fade(@sapUiExtraLightBG, 80%);
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
}
/*
 * Enforces 'auto' width. To be used in combination
 * with pre-defined margin classes to remove any '100%'
 * width's that might be set.
 */
.sapUiForceWidthAuto { width: auto !important; }

/*
 * Pre-defined margins classes. These contain css margin
 * properties which are flagged 'important' to make sure
 * margins that come with a control are overwritten (an
 * example for a control with a pre defined margin is the
 * sap.m.List).
 *
 * In case your control comes with width '100%', horizontal
 * margins will not work properly. If your control has a
 * width property (which is usually the case), you should
 * set that property to 'auto'.
 *
 * There are some control's though which do not have a width
 * property but still have a default width of '100%'
 * (one example would be the SimpleForm). For these cases,
 * please use css class 'sapUiForceWidthAuto' to which replace
 * your control's default width with value 'auto'.
 */

/* Margins all around */
.sapUiTinyMargin 	{ margin: @sapUiMarginTiny !important; }
.sapUiSmallMargin 	{ margin: @sapUiMarginSmall !important; }
.sapUiMediumMargin 	{ margin: @sapUiMarginMedium !important; }
.sapUiLargeMargin 	{ margin: @sapUiMarginLarge !important; }

/* Two-sided margins */
.sapUiTinyMarginBeginEnd {
	margin-left: @sapUiMarginTiny !important;
	margin-right: @sapUiMarginTiny !important;
}
.sapUiTinyMarginTopBottom {
	margin-top: @sapUiMarginTiny !important;
	margin-bottom: @sapUiMarginTiny !important;
}
.sapUiSmallMarginBeginEnd {
	margin-left: @sapUiMarginSmall !important;
	margin-right: @sapUiMarginSmall !important;
}
.sapUiSmallMarginTopBottom {
	margin-top: @sapUiMarginSmall !important;
	margin-bottom: @sapUiMarginSmall !important;
}
.sapUiMediumMarginBeginEnd {
	margin-left: @sapUiMarginMedium !important;
	margin-right: @sapUiMarginMedium !important;
}
.sapUiMediumMarginTopBottom {
	margin-top: @sapUiMarginMedium !important;
	margin-bottom: @sapUiMarginMedium !important;
}
.sapUiLargeMarginBeginEnd {
	margin-left: @sapUiMarginLarge !important;
	margin-right: @sapUiMarginLarge !important;
}
.sapUiLargeMarginTopBottom {
	margin-top: @sapUiMarginLarge !important;
	margin-bottom: @sapUiMarginLarge !important;
}

/* Single-sided margins */
.sapUiTinyMarginTop    { margin-top: @sapUiMarginTiny !important; }
.sapUiTinyMarginBottom { margin-bottom: @sapUiMarginTiny !important; }
.sapUiTinyMarginBegin  { margin-left: @sapUiMarginTiny !important; }
.sapUiTinyMarginEnd    { margin-right: @sapUiMarginTiny !important; }

.sapUiSmallMarginTop    { margin-top: @sapUiMarginSmall !important; }
.sapUiSmallMarginBottom { margin-bottom: @sapUiMarginSmall !important; }
.sapUiSmallMarginBegin  { margin-left: @sapUiMarginSmall !important; }
.sapUiSmallMarginEnd    { margin-right: @sapUiMarginSmall !important; }

.sapUiMediumMarginTop    { margin-top: @sapUiMarginMedium !important; }
.sapUiMediumMarginBottom { margin-bottom: @sapUiMarginMedium !important; }
.sapUiMediumMarginBegin  { margin-left: @sapUiMarginMedium !important; }
.sapUiMediumMarginEnd    { margin-right: @sapUiMarginMedium !important; }

.sapUiLargeMarginTop    { margin-top: @sapUiMarginLarge !important; }
.sapUiLargeMarginBottom { margin-bottom: @sapUiMarginLarge !important; }
.sapUiLargeMarginBegin  { margin-left: @sapUiMarginLarge !important; }
.sapUiLargeMarginEnd    { margin-right: @sapUiMarginLarge !important; }

/* Negative two-sided margins */
.sapUiTinyNegativeMarginBeginEnd {
	margin-left: -@sapUiMarginTiny !important;
	margin-right: -@sapUiMarginTiny !important;
}
.sapUiSmallNegativeMarginBeginEnd {
	margin-left: -@sapUiMarginSmall !important;
	margin-right: -@sapUiMarginSmall !important;
}
.sapUiMediumNegativeMarginBeginEnd {
	margin-left: -@sapUiMarginMedium !important;
	margin-right: -@sapUiMarginMedium !important;
}
.sapUiLargeNegativeMarginBeginEnd {
	margin-left: -@sapUiMarginLarge !important;
	margin-right: -@sapUiMarginLarge !important;
}


/*
 * Class for responsive margins which adapts to the screen size of the currently used device
 */
@media (max-width:599px) {
	.sapMSplitContainerHideMode > .sapMSplitContainerDetail .sapUiResponsiveMargin,
	.sapMSplitContainerPortrait > .sapMSplitContainerDetail .sapUiResponsiveMargin,
	.sapUiResponsiveMargin {
		margin: 0 0 1rem 0 !important;
	}
}

@media (min-width:600px) and (max-width:1023px) {
	.sapMSplitContainerHideMode > .sapMSplitContainerDetail .sapUiResponsiveMargin,
	.sapUiResponsiveMargin {
		margin: 1rem !important;
	}
}

@media (min-width:1024px) {
	.sapMSplitContainerHideMode > .sapMSplitContainerDetail .sapUiResponsiveMargin,
	.sapUiResponsiveMargin {
		margin: 1rem 2rem !important;
	}
}

/*
 * Content of SplitContainer Master
 * (Left hand-side of SplitContainer)
 */
.sapMSplitContainerMaster .sapUiResponsiveMargin
{
	margin: 0 0 1rem 0 !important;
}

/*
 * Content of SplitContainer Detail
 * (Right hand-side of SplitContainer)
 */
.sapMSplitContainerDetail .sapUiResponsiveMargin{
	margin: 1rem !important;
}


/*
 * No margins, use these classes to remove existing margins.
 * IMPORTANT: THESE CLASSES MUST COME AFTER ALL OTHER PRE-DEFINED MARGINS
 * to make sure that their 'IMPORTANT' statement wins
 */
.sapUiNoMargin    { margin: 0 !important; } /*Removes ALL margins*/
/*Use the following to remove a margin on a particular side of your container*/
.sapUiNoMarginTop    { margin-top: 0 !important; }
.sapUiNoMarginBottom { margin-bottom: 0 !important; }
.sapUiNoMarginBegin  { margin-left: 0 !important; }
.sapUiNoMarginEnd    { margin-right: 0 !important; }

.sapUiInvisibleText, .sapUiHiddenPlaceholder {
	display: none !important;
}

/* hides the content to sighted users, but still allow it to be read by screen readers */
.sapUiPseudoInvisibleText {
	position: absolute !important;
	clip: rect(1px, 1px, 1px, 1px);
	user-select: none;
	left: 0;
	top: 0;
	font-size: 0;
}

/* CSS classes for bridging two buttons in the technical info dialog */
.sapMBtn.sapUiDebugTechnicalInfoAssistantButton {
	margin-right: 0 !important;
}

.sapMBtn.sapUiDebugTechnicalInfoAssistantButton>.sapMBtnInner {
	border-top-right-radius: 0 !important;
	border-bottom-right-radius: 0 !important;
}

.sapMBtn.sapUiDebugTechnicalInfoAssistantSettingsButton {
	margin-left: 0 !important;
}

.sapMBtn.sapUiDebugTechnicalInfoAssistantSettingsButton>.sapMBtnInner  {
	border-top-left-radius: 0 !important;
	border-bottom-left-radius: 0 !important;
}
/* END "shared.less" */


/* START "BlindLayer.less" */
/* ======================================= */
/* CSS for control sap.ui.core/BlindLayer  */
/* Base theme                              */
/* ======================================= */

.sapUiBliLy {
	position: absolute;
	display: inline-block;
}

.sapUiBliLy > iframe {
	background-color: transparent;
	border: none;
	margin: 0;
	padding: 0;
	position: absolute;
	opacity: 0.01;
	filter: alpha(opacity=1);
	width: 100%;
	height: 100%;
}

.sapUiNotUserSelectable {
	-webkit-touch-callout: none; /* iOS Safari */
	-webkit-user-select: none;   /* Chrome/Safari/Opera */
	-khtml-user-select: none;    /* Konqueror */
	-moz-user-select: none;      /* Firefox */
	user-select: none;           /* Non-prefixed version */
}

.sapUiUserSelectable {
	-webkit-touch-callout: text; /* iOS Safari */
	-webkit-user-select: text;   /* Chrome/Safari/Opera */
	-khtml-user-select: text;    /* Konqueror */
	-moz-user-select: text;      /* Firefox */
	user-select: text;           /* Non-prefixed version */
}
/* END "BlindLayer.less" */

/* START "BrowserScrollbar.less" */
/* ============================================= */
/* CSS for control sap.ui.core/BrowserScrollbar  */
/* Base theme                                    */
/* ============================================= */

/****** Firefox ******/

html.sap-desktop:not(.sapUiNativeScrollbars) {
	scrollbar-color: @sapUiScrollBarFaceColor @sapUiScrollBarTrackColor;
}

/****** Safari + Chrome on Desktop ******/

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar:horizontal {
	height: @sapUiScrollBarDimension;
}

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar:vertical {
	width: @sapUiScrollBarDimension;
}

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar {
	background-color: @sapUiScrollBarTrackColor;
}

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar-thumb {
	background-color: @sapUiScrollBarFaceColor;
}

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar-thumb:hover {
	background-color: @sapUiScrollBarHoverFaceColor;
}

html.sap-desktop:not(.sapUiNativeScrollbars) ::-webkit-scrollbar-corner {
	background-color: @sapUiScrollBarTrackColor;
}
/* END "BrowserScrollbar.less" */

/* START "BusyIndicator.less" */
/* ========================================== */
/* CSS for control sap.ui.core/BusyIndicator  */
/* Base theme                                 */
/* ========================================== */

.sapUiBusy {
	background-image: url(img/Busy.gif);
	display: block;
	width: 48px;
	height: 48px;
	outline: none;
	cursor: wait;

	top: 0 !important;
}

.sapUiBlyBusy {
	cursor: wait;
}
/* END "BusyIndicator.less" */

/* START "CommandShortcutHints.less" */
/* =============================== */
/* CSS for a command shortcut hint */
/* Base theme                      */
/* =============================== */

.sapUiHintContainer {
	background: @sapUiBaseBG;
	border: none;
	border-radius: 0.0625rem;
	box-shadow: @sapUiContentShadow1;
	white-space: nowrap;
}

.sapUiHintText {
	font-family: @sapUiFontFamily;
	font-size: @sapMFontSmallSize;
	color: @sapUiBaseText;
	padding: 0 0.5rem;
	line-height: 1rem;
}
/* END "CommandShortcutHints.less" */

/* START "DragAndDrop.less" */
.sapUiDnDDragging {
	opacity: 0.5;
}

.sapUiDnDNoScrolling {
	overflow: hidden;
}

.sapUiDnDGhostContainer {
	position: absolute;
	top: -9999px;
	left: -9999px;
}

.sapUiDnDIndicator {
	position: absolute;
	pointer-events: none;
	z-index: 99;

	&[data-drop-position=Between] {
		background: @sapUiContentDragAndDropActiveColor;

		&:before {
			content: "";
			position: absolute;
			width: 0.25rem;
			height: 0.25rem;
			border-radius: 0.25rem;
			border: 0.125rem solid @sapUiContentDragAndDropActiveColor;
			background: @sapUiWhiteBG;
			pointer-events: none;
		}

		&[data-drop-layout=Vertical] {
			height: 0.125rem;

			&:before {
				top: -0.175rem;
			}

			&:before {
				left: 0;
			}
		}

		&[data-drop-layout=Horizontal] {
			width: 0.125rem;

			&:before {
				left: -0.175rem;
			}

			&:before {
				top: 0;
			}
		}
	}

	&[data-drop-position=On] {
		background: @sapUiDragAndDropActiveBackground;
		border: 0.125rem solid @sapUiContentDragAndDropActiveColor;
		box-sizing: border-box;
	}
}

[data-sap-ui-draggable=true] {
	cursor: grab;
	cursor: -moz-grab;
	cursor: -webkit-grab;
}

[data-sap-ui-draggable=true]:active {
	cursor: grabbing;
	cursor: -moz-grabbing;
	cursor: -webkit-grabbing;
}
/* END "DragAndDrop.less" */


/* START "SAP-icons.less" */
// NOTE: This file must be kept in sync with SAP-icons.css

@font-face {
	font-family: "SAP-icons";
	src:
		@sapUiIconFontUrl format('woff2'),
		local('SAP-icons'); /* fallback to local installed font in case it can't be loaded (e.g. font download is disabled due to browser security settings) */
	font-weight: normal;
	font-style: normal;
}

/* END "SAP-icons.less" */

/* START "Icon.less" */
/* ================================= */
/* CSS for control sap.ui.core/Icon  */
/* Base theme                        */
/* ================================= */

.sapUiIcon {
	cursor: default;
	text-align: center;
	display: inline-block;
	vertical-align: baseline;
	line-height: 1;
	position: relative;
}

.sapUiTableCell > .sapUiTableCellInner > .sapUiIcon,
.sapMListTblCell > .sapUiIcon {
	vertical-align: middle;
}

.sapUiIconPointer {
	cursor: pointer;
}

.sapUiIcon:focus {
	outline-width: @sapUiContentFocusWidth;
	outline-style: @sapUiContentFocusStyle;
	outline-color: @sapUiContentFocusColor;
}

.sapUiIcon::before {
	content: attr(data-sap-ui-icon-content);
	speak: none;
	font-weight: normal;
	-webkit-font-smoothing: antialiased;
}

.sapUiIcon > .sapUiIconTitle {
	position: absolute;
	width: 100%;
	height: 100%;
	left: 0;
	top: 0;
}

/*
 * The mirroring of icon is done on the pesudo element and not the root DOM.
 * Because:
 *  1. All direction related css styles are flipped in RTL, for example padding-left
 *   is changed to padding right in RTL.
 *  2. The mirroring of an icon in RTL mode flips the css style again which results
 *   in the wrong direction.
 *  3. Custom CSS style should be set on the root DOM and not the pesudo element.
 */
html[dir=rtl] .sapUiIconMirrorInRTL:not(.sapUiIconSuppressMirrorInRTL) {
	&::before, &::after /* some controls render the icon using 'after' pesudo element */ {
		transform: scale(-1,1);
		-webkit-transform: scale(-1,1); /* Safari and Chrome */
		display: inline-block; /* pesudo element has display: inline by default and can't apply the transform css style for RTL mode*/
	}
}

/**
 * The Default color and the semantic colors for Icon which always points to the variable across themes.
 */
.sapUiIconColorDefault {
	color: @sapUiContentIconColor;
}

.sapUiIconColorContrast {
	color: @sapUiContentContrastIconColor;
}

.sapUiIconColorNeutral {
	color: @sapUiNeutralElement;
}

.sapUiIconColorCritical {
	color: @sapUiCriticalElement;
}

.sapUiIconColorPositive {
	color: @sapUiPositiveElement;
}

.sapUiIconColorNegative {
	color: @sapUiNegativeElement;
}

.sapUiIconColorNonInteractive {
	color: @sapUiContentNonInteractiveIconColor;
}

.sapUiIconColorTile {
	color: @sapUiTileIconColor;
}

.sapUiIconColorMarker {
	color: @sapUiContentMarkerIconColor;
}

.sapUiIconBGColorDefault {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiContentIconColor;
}

.sapUiIconBGColorContrast {
	color: @sapUiContentIconColor;
	background-color: @sapUiContentContrastIconColor;
}

.sapUiIconBGColorNeutral {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiNeutralElement;
}

.sapUiIconBGColorCritical {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiCriticalElement;
}

.sapUiIconBGColorPositive {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiPositiveElement;
}

.sapUiIconBGColorNegative {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiNegativeElement;
}

.sapUiIconBGColorNonInteractive {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiContentNonInteractiveIconColor;
}

.sapUiIconBGColorTile {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiTileIconColor;
}

.sapUiIconBGColorMarker {
	color: @sapUiGroupContentBackground;
	background-color: @sapUiContentMarkerIconColor;
}

/* END "Icon.less" */


/* START "LocalBusyIndicator.less" */
/* =============================================== */
/* CSS for control sap.ui.core/LocalBusyIndicator  */
/* Base theme                                      */
/* =============================================== */

@_sap_ui_core_LocalBusyIndicator_Background: fade(@sapBackgroundColor, 72%);
@_sap_ui_core_LocalBusyIndicator_BackgroundIE: @sapBackgroundColor;

@_sap_ui_core_LocalBusyIndicator_Color: @sapBrandColor;

@_sap_ui_core_LocalBusyIndicator_BorderRadius: 100%;

@_sap_ui_core_LocalBusyIndicator_SizeMedium: 1rem;
@_sap_ui_core_LocalBusyIndicator_SizeBig: 2rem;

.sapUiBlockLayer, .sapUiLocalBusyIndicator {
	background-color: @_sap_ui_core_LocalBusyIndicator_Background;
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
}

.sapUiLocalBusyIndicator {
	opacity: 0;
	transition: opacity 0.3s ease-in;
	outline: none;

	&:focus:after {
		content: "";
		position: absolute;
		left: 0;
		top: 0;
		right: 0;
		bottom: 0;
		border-radius: 0.375rem;
		border: @sapUiContentFocusWidth @sapUiContentFocusStyle @sapUiContentFocusColor;
		pointer-events: none;
	}
}

.sapUiBlockLayer:not(:last-child) {
	display: none;
}

.sapUiBlockLayer.sapUiPlaceholder {
	display: block;
	z-index: 1;
}

//  Make sure blocked layers are not "nested", and in case of busy indicators the animations do not overlay each other
[__is-busy] .sapUiLocalBusy .sapUiBlockLayer,
.sapUiLocalBusy .sapUiLocalBusy .sapUiBlockLayer {
	display: none;
}

.sapUiHiddenBusyIndicatorAnimation .sapUiLocalBusyIndicatorAnimation {
	display: none;
}

.sapUiLocalBusyIndicatorFade {
	opacity: 1;
}

/* Class for medium sized indicator in control overlay */
.sapUiLocalBusyIndicatorSizeMedium,
.sapUiLocalBusyIndicatorSizeSection {
	font-size: @_sap_ui_core_LocalBusyIndicator_SizeMedium;
}

/* Class for fullscreen block overlay */
.sapUiLocalBusyIndicatorSizeBig {
	font-size: @_sap_ui_core_LocalBusyIndicator_SizeBig;
	background-color: transparent;

}

/* Centers the busy indicator markers */
.sapUiLocalBusyIndicatorAnimation {
	position: absolute;
	width: 3em;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%);
}

/* indicator bubble */
.sapUiLocalBusyIndicatorAnimation > div {
	width: 1em;
	height: 1em;
	border-radius: @_sap_ui_core_LocalBusyIndicator_BorderRadius;
	display: block;
	float: left;
	margin: 0px;
	position: relative;
	text-indent: 1px;
}

/* General pseudo-element styles for background/shadow animation */
.sapUiLocalBusyIndicatorAnimation > div::before,
.sapUiLocalBusyIndicatorAnimation > div::after {
	content: "";
	opacity: 1;
	position: absolute;
	z-index: -1;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	border-radius: @_sap_ui_core_LocalBusyIndicator_BorderRadius;
}

/* Background animation element */
.sapUiLocalBusyIndicatorAnimation > div::before {
	background: fade(@_sap_ui_core_LocalBusyIndicator_Color, 100%);
}

/* Shadow animation element */
.sapUiLocalBusyIndicatorAnimation > div::after {
	box-shadow: inset 0px 0px 2px 1px fade(@_sap_ui_core_LocalBusyIndicator_Color, 80%);
}

/* Animations Starting Classes */
.sapUiLocalBusyIndicatorAnimation > div,
.sapUiLocalBusyIndicatorAnimation > div::before,
.sapUiLocalBusyIndicatorAnimation > div::after {
	animation-fill-mode: both;
}

/* Big Animation for Elments >= (3rem x 3rem) */
.sapUiLocalBusyIndicatorAnimStandard > div {
	animation: sapUiBusyAnimationStandard 1.8s infinite ease-in-out;
}

.sapUiLocalBusyIndicatorAnimStandard > div::before {
	animation: sapUiBusyAnimationStandardBackground 1.8s infinite ease-in-out;
}

.sapUiLocalBusyIndicatorAnimStandard > div::after {
	animation: sapUiBusyAnimationStandardShadow 1.8s infinite ease-in-out;
}

.sapUiLocalBusyIndicatorAnimStandard > div:nth-child(1) {
	animation-delay: -0.32s;
}

.sapUiLocalBusyIndicatorAnimStandard > div:nth-child(2) {
	animation-delay: -0.16s;
}

/* Small animation for elements < (3rem x 3rem) */
.sapUiLocalBusyIndicatorAnimSmall > div {
	animation: sapUiBusyAnimationSmall 1.6s infinite ease-in-out;
}

.sapUiLocalBusyIndicatorAnimSmall > div::before {
	animation: sapUiBusyAnimationSmallBackground 1.6s infinite ease-in-out;
}

.sapUiLocalBusyIndicatorAnimSmall > div::after {
	animation: sapUiBusyAnimationSmallShadow 1.6s infinite ease-in-out;
}

html[data-sap-ui-animation-mode="none"] {
	.sapUiLocalBusyIndicator {
		transition: none;
	}

	.sapUiLocalBusyIndicatorAnimStandard,
	.sapUiLocalBusyIndicatorAnimSmall {
		> div,
		> div::before,
		> div::after {
			animation: none;
			transform: scale(0.8);
		}
	}
}

html[data-sap-ui-animation-mode="basic"],
html[data-sap-ui-animation-mode="minimal"] {
	.sapUiLocalBusyIndicatorAnimStandard,
	.sapUiLocalBusyIndicatorAnimSmall {
		> div,
		> div::before,
		> div::after {
			animation-duration: 6s;
		}

		> div:nth-child(1) {
			animation-delay: -1.2s;
		}

		> div:nth-child(2) {
			animation-delay: -0.6s;
		}
	}
}

/* marker class for switching horizontal and small animation */
.sapUiLocalBusyIndicatorAnimSmall > div:nth-child(1),
.sapUiLocalBusyIndicatorAnimSmall > div:nth-child(3) {
	visibility: hidden;
}

#sapUiBusyIndicator {
	right: 0;
}

#sapUiBusyIndicator > .sapUiLocalBusyIndicatorFade {
	cursor: wait;
}

/**
 * Keyframe definitions
 */
.mixin-standard-background-animation-frames {
	0%, 80%, 100% {
		opacity: 1;
	}
	40% {
		opacity: 0.1;
	}
}

.mixin-standard-shadow-animation-frames {
	0%, 80%, 100% {
		opacity: 0;
	}
	40% {
		opacity: 1;
	}
}

.mixin-small-background-animation-frames {
	0%, 100% {
		opacity: 1;
	}
	50% {
		opacity: 0.1;
	}
}

.mixin-small-shadow-animation-frames {
	0%, 100% {
		opacity: 0;
	}
	50% {
		opacity: 1;
	}
}

/**
 * Animations
 */
@keyframes sapUiBusyAnimationStandard {
	0%, 80%, 100% {
		transform: scale(0.4);
	}
	40% {
		transform: scale(1);
	}
}

@keyframes sapUiBusyAnimationStandardBackground { .mixin-standard-background-animation-frames; }

@keyframes sapUiBusyAnimationStandardShadow { .mixin-standard-shadow-animation-frames; }

@keyframes sapUiBusyAnimationSmall {
	0%, 100% {
		transform: scale(0.2);
	}
	50% {
		transform: scale(1);
	}
}
@keyframes sapUiBusyAnimationSmallBackground { .mixin-small-background-animation-frames; }

@keyframes sapUiBusyAnimationSmallShadow { .mixin-small-shadow-animation-frames; }


// #### RETROFIT ####

:root {
	--ui5_web_components_busy_indicator_display: flex;
	--ui5_web_components_busy_indicator_background-color: @_sap_ui_core_LocalBusyIndicator_Background;
}

//  Make sure blocked layers are not "nested", and in case of busy indicators the animations do not overlay each other
.sapUiLocalBusy {
	--ui5_web_components_busy_indicator_display: none;
}
/* END "LocalBusyIndicator.less" */

/* START "media.less" */
/************ Media queries for screen sizes ************

Usage:

@media (@_sap_ui_core_media_StdDesktop) {
      .test {
            width: 50em;
      }
}

*********************************************************/


/* see sap.ui.Device.media.RANGESETS.SAP_STANDARD*/
@_sap_ui_core_media_StdDesktop:  ~"screen and (min-width : 1024px)";
@_sap_ui_core_media_StdTablet:  ~"screen and (min-width : 600px) and (max-width : 1023px)";
@_sap_ui_core_media_StdPhone:  ~"screen and (max-width : 599px)";

/* see sap.ui.Device.media.RANGESETS.SAP_3STEPS*/
@_sap_ui_core_media_3StepL:  ~"screen and (min-width : 960px)";
@_sap_ui_core_media_3StepM:  ~"screen and (min-width : 520px) and (max-width : 959px)";
@_sap_ui_core_media_3StepS:  ~"screen and (max-width : 519px)";

/* see sap.ui.Device.media.RANGESETS.SAP_4STEPS*/
@_sap_ui_core_media_4StepXL:  ~"screen and (min-width : 960px)";
@_sap_ui_core_media_4StepL:  ~"screen and (min-width : 760px) and (max-width : 959px)";
@_sap_ui_core_media_4StepM:  ~"screen and (min-width : 520px) and (max-width : 759px)";
@_sap_ui_core_media_4StepS:  ~"screen and (max-width : 519px)";

/* see sap.ui.Device.media.RANGESETS.SAP_6STEPS*/
@_sap_ui_core_media_6StepXXL:  ~"screen and (min-width : 960px)";
@_sap_ui_core_media_6StepXL:  ~"screen and (min-width : 768px) and (max-width : 959px)";
@_sap_ui_core_media_6StepL:  ~"screen and (min-width : 541px) and (max-width : 767px)";
@_sap_ui_core_media_6StepM:  ~"screen and (min-width : 400px) and (max-width : 540px)";
@_sap_ui_core_media_6StepS:  ~"screen and (min-width : 241px) and (max-width : 399px)";
@_sap_ui_core_media_6StepXS:  ~"screen and (max-width : 240px)";
/* END "media.less" */

/* START "parameterClasses.less" */

/* CSS parameters which are available in base theme */

/* font */
.sapThemeFont {
	font-family: @sapUiFontFamily !important;
	font-size: @sapUiFontSize !important;
}
.sapThemeFontFamily {
	font-family: @sapUiFontFamily !important;
}
.sapThemeFontSize {
	font-size: @sapUiFontSize !important;
}

/* text color */
.sapThemeText,
.sapThemeText-asColor {
	color: @sapUiBaseText !important;
}
.sapThemeText-asBackgroundColor {
	background-color: @sapUiBaseText !important;
}
.sapThemeText-asBorderColor {
	border-color: @sapUiBaseText !important;
}
.sapThemeText-asOutlineColor {
	outline-color: @sapUiBaseText !important;
}

/* text color inverted */
.sapThemeTextInverted,
.sapThemeTextInverted-asColor {
	color: @sapUiContentContrastTextColor !important;
}

/* base bg */
.sapThemeBaseBG,
.sapThemeBaseBG-asBackgroundColor {
	background-color: @sapUiBaseBG !important;
}
.sapThemeBaseBG-asBorderColor {
	border-color: @sapUiBaseBG !important;
}
.sapThemeBaseBG-asColor {
	color: @sapUiBaseBG !important;
}

/* brand color */
.sapThemeBrand,
.sapThemeBrand-asColor {
	color: @sapUiBrand !important;
}
.sapThemeBrand-asBorderColor {
	border-color: @sapUiBrand !important;
}
.sapThemeBrand-asBackgroundColor {
	background-color: @sapUiBrand !important;
}
.sapThemeBrand-asOutlineColor {
	outline-color: @sapUiBrand !important;
}

/* highlight color */
.sapThemeHighlight,
.sapThemeHighlight-asColor {
	color: @sapUiHighlight !important;
}
.sapThemeHighlight-asBorderColor {
	border-color: @sapUiHighlight !important;
}
.sapThemeHighlight-asBackgroundColor {
	background-color: @sapUiHighlight !important;
}
.sapThemeHighlight-asOutlineColor {
	outline-color: @sapUiHighlight !important;
}

/* border color */
.sapThemeForegroundBorderColor,
.sapThemeForegroundBorderColor-asBorderColor {
	border-color: @sapUiContentForegroundBorderColor  !important;
}
/* END "parameterClasses.less" */

/* START "ScrollBar.less" */
/* ====================================== */
/* CSS for control sap.ui.core/ScrollBar  */
/* Base theme                             */
/* ====================================== */

.sapUiScrollBarTouch {
	-webkit-overflow-scrolling: auto;
}

.sapUiScrollBarTouch ::-webkit-scrollbar {
	height: 7px;
	width: 7px;
	-webkit-appearance: none;
}

.sapUiScrollBarTouch ::-webkit-scrollbar-thumb {
	border-radius: 4px;
	background-color: rgba(0,0,0,.5);
	-webkit-box-shadow: 0 0 1px rgba(255,255,255,.5);
}
/* END "ScrollBar.less" */

/* START "Shadow.less" */
.sapUiShd {
	box-shadow: @sapUiShadow;
}
/* END "Shadow.less" */

/* START "TechnicalInfo.less" */
.sapUiTInf {
	border: 1px solid @sapUiMediumBorder;
	background: @sapUiExtraLightBG;
	padding: 6px;
}

.sapUiTInfCfg {
	font-size:0.9em;
	overflow-y:auto;
	max-height:12em;
}

.sapUiTInfMList {
	font-size:0.9em;
	color: @sapUiTextDisabled;
	overflow-y:auto;
	max-height:12em;
}

.sapUiTInf > table > tbody > tr > td,
.sapUiTInfMList,
.sapUiTInfM {
	-webkit-user-select: text;
	user-select: text;
}

.sapUiTInfMEmbd {
	color:#aaaaaa;
}

.sapUiTInfMFail {
	text-decoration:line-through;
}

.sapUiTInfMMore, .sapUiTInfPCfg {
	text-decoration: none;
	color: @sapLinkColor;
	cursor:pointer;
}

.sapUiTInfPMoreHidden {
	display:none;
}

.sapUiTInfPDiag {
	border: 1px solid @sapUiMediumBorder;
	background: @sapUiExtraLightBG;
	padding: 6px;
	font-size:0.9em;
}

.sapUiTInfPDiag > h1 {
	font-size: 1em;
	font-weight: normal;
}

.sapUiTInfPDiag > h3 {
	font-size: 0.9em;
	font-weight: normal;
	margin-bottom: 0px;
}

.sapUiTInfPList {
	font-size: 0.75em;
	color: @sapUiTextDisabled;
	background: white;
	overflow-y: scroll;
	max-height: 30em;
}

.sapUiTInfPList .package > .expander {
	display: inline-block;
	color: black;
	background-color: #fcfcfc;
	width: 12px;
	text-align: center;
	border-radius: 4px;
	cursor: pointer;
}

.sapUiTInfPList .package > .name,
.sapUiTInfPList .module > .name {
	margin: 2px;
	padding: 2px 4px;
	display: inline-block;
	border-radius: 3px;
	cursor: pointer;
}

.sapUiTInfPList .package > .name {
	color: black;
	background-color: @sapBackgroundColor;
}

.sapUiTInfPList .module > .name {
	margin-left: 14px; /* 12px + 2px standard margin */
	color: black;
	background-color: @sapBackgroundColor;
}

.sapUiTInfPList .children {
	padding-left: 1em;
	/* border: 1px dotted lightgrey; */
}

.sapUiTInfPList .children.none {
	display: none;
}

.sapUiTInfPList .children.packages {
	display: block;
}

.sapUiTInfPList .children.packages > .package {
}

.sapUiTInfPList .children.packages > .module {
	display: none;
}

.sapUiTInfPList .children.all {
	display: block;
}

.sapUiTInfPList .package.selected > .name, .sapUiTInfPList .module.selected > .name {
	color: white;
	background-color: blue !important;
}

.sapUiTInfPList .package.selected .name, .sapUiTInfPList .module.selected > .name {
	color: white;
	background-color: lightblue;
}

.sapUiTInfPList .selected .name {
	color: white;
	background-color: #ccccff;
}

.sapUiTInfPDiag .result {
	font-size: 0.9em;
	margin: 8px 4px;
	width: 600px;
}

.sapUiTInfPDiag .result > span {
	word-wrap: break-word;
}

.sapUiTInfPDiag .footer {
	padding-top: 5px;
}

.sapUiTInfPDiag .footer > * {
	float: right;
	margin: 2px 8px;
}

/* END "TechnicalInfo.less" */

/* START "View.less" */
/* ================================= */
/* CSS for control sap.ui.core/View  */
/* Base theme                        */
/* ================================= */

.sapUiView {
	display: inline-block;
}

.sapUiViewDisplayBlock {
	display: block;
}
/* END "View.less" */

